@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005 by Albert Astals Cid <tsdgeos@terra.es>            *
+ *   Copyright (C) 2005-2006 by Albert Astals Cid <aacid@kde.org>          *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -7,50 +7,47 @@
  *   (at your option) any later version.                                   *
  ***************************************************************************/
 
-#include <kaction.h>
-#include <kapplication.h>
+#include "button.h"
+
 #include <kconfig.h>
+#include <ksharedconfig.h>
+#include <kshortcut.h>
 #include <kstandarddirs.h>
 #include <kdebug.h>
-
-#include "button.h"
+#include <kglobal.h>
+#include <kconfiggroup.h>
 
 button::button(blinkenGame::color c) : m_selected(false), m_color(c)
 {
-	KConfig *kc = kapp->config();
-	kc->setGroup("General");
+	KConfigGroup kc(KGlobal::config(), "General");
 	QString cs = getColorString();
-	QString pixmap = QString("images/%1h.png").arg(cs);
 	
 	switch (c)
 	{
 		case blinkenGame::blue:
-			m_key = kc->readNumEntry(cs, Qt::Key_3);
+			m_key = kc.readEntry(cs, int(Qt::Key_3));
 		break;
 		
 		case blinkenGame::yellow:
-			m_key = kc->readNumEntry(cs, Qt::Key_1);
+			m_key = kc.readEntry(cs, int(Qt::Key_1));
 		break;
 		
 		case blinkenGame::red:
-			m_key = kc->readNumEntry(cs, Qt::Key_2);
+			m_key =kc.readEntry(cs, int(Qt::Key_2));
 		break;
 		
 		case blinkenGame::green:
-			m_key = kc->readNumEntry(cs, Qt::Key_4);
+			m_key = kc.readEntry(cs, int(Qt::Key_4));
 		break;
 		
 		default:
 			// never happens
 		break;
 	}
-	
-	m_highlighted = new QPixmap(locate("appdata", pixmap));
 }
 
 button::~button()
 {
-	delete m_highlighted;
 }
 
 void button::setShortcut(int key)
@@ -58,10 +55,9 @@ void button::setShortcut(int key)
 	m_key = key;
 	m_selected = false;
 	
-	KConfig *kc = kapp->config();
-	kc->setGroup("General");
-	kc->writeEntry(getColorString(), key);
-	kc->sync();
+	KConfigGroup kc(KGlobal::config(), "General");
+	kc.writeEntry(getColorString(), key);
+	kc.sync();
 }
 
 QString button::shortcut() const
@@ -84,11 +80,6 @@ bool button::selected() const
 	return m_selected;
 }
 
-QPixmap *button::pixmap() const
-{
-	return m_highlighted;
-}
-
 QString button::getColorString() const
 {
 	switch (m_color)
@@ -115,5 +106,5 @@ QString button::getColorString() const
 	}
 	
 	// never happens
-	return QString::null;
+	return QString();
 }
