@@ -27,12 +27,11 @@ QString Object::toString() const
 	return e.result();
 }
 
-Ci::Ci(const Object * o) : Object(o->type())
+Object* Ci::copy() const
 {
-	Q_ASSERT(m_type==Object::variable);
-	const Ci *c = (Ci*) o;
-	m_name = c->name();
-	m_function = c->m_function;
+	Ci *c = new Ci(m_name);
+	c->m_function = m_function;
+	return c;
 }
 
 QString Ci::visit(ExpressionWriter* e) const
@@ -48,19 +47,22 @@ QString Ci::toMathML() const
 		return QString("<ci>%1</ci>").arg(m_name);
 }
 
-Object::ValueType Object::valueType() const
+bool Ci::matches(const Object* exp, QMap<QString, const Object*>* found) const
 {
-	switch(m_type) {
-		case Object::value:
-			return Real;
-		case Object::container: {
-			const Container *c=(const Container*) this;
-			if(c->containerType()==Container::vector)
-				return Vector;
-			break;
+	bool ret=false;
+	if(found->contains(m_name)) {
+		const Object* v=found->value(m_name);
+		if(v) { //If already been found
+			ret=Container::equalTree(exp, v);
+		} else {
+			found->insert(m_name, exp);
+			ret=true;
+		}
+	} else {
+		ret = (Object::variable==exp->type());
+		if(ret) {
+			ret = static_cast<const Ci*>(exp)->name()==m_name;
 		}
-		default:
-			break;
 	}
-	return Null;
+	return ret;
 }
