@@ -22,11 +22,13 @@
 #include <QWidget>
 #include <QSortFilterProxyModel>
 
+class Variables;
 class QLabel;
 class QModelIndex;
 class Graph2D;
 class FunctionsModel;
 class OperatorsModel;
+class QtMmlWidget;
 
 /**
 	@author Aleix Pol
@@ -36,7 +38,7 @@ class Dictionary : public QWidget
 Q_OBJECT
 	public:
 		Dictionary(QWidget *p=0);
-		virtual ~Dictionary(){}
+		virtual ~Dictionary();
 		
 		QSortFilterProxyModel* model() const { return m_sortProxy; }
 		
@@ -49,10 +51,12 @@ Q_OBJECT
 		QLabel *m_descr;
 		QLabel *m_sample;
 		QLabel *m_example;
-		//KFormula *m_formula;
+		
+		QtMmlWidget* m_formula;
 		Graph2D *m_graph;
 		FunctionsModel *m_funcs;
 		OperatorsModel *m_ops;
+		Variables* m_vars;
 		QSortFilterProxyModel *m_sortProxy;
 };
 
