@@ -12,11 +12,12 @@
 
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-// 02111-1307, USA.
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+// 02110-1301, USA.
 
 #include "kseg-filter.h"
 
+#include "filters-common.h"
 #include "kseg-defs.h"
 
 #include "../kig/kig_document.h"
@@ -39,6 +40,7 @@
 #include "../objects/other_type.h"
 #include "../objects/point_imp.h"
 #include "../objects/point_type.h"
+#include "../objects/polygon_imp.h"
 #include "../objects/polygon_type.h"
 #include "../objects/transform_types.h"
 #include "../objects/vector_type.h"
@@ -50,6 +52,8 @@
 #include <qdatastream.h>
 #include <qbuffer.h>
 
+#include <klocale.h>
+
 KigFilterKSeg::KigFilterKSeg()
 {
 }
@@ -65,7 +69,7 @@ bool KigFilterKSeg::supportMime( const QString& mime )
 
 struct drawstyle
 {
-  Q_INT8 pointstyle;
+  qint8 pointstyle;
   QFont font;
   QPen pen;
   QBrush brush;
@@ -105,7 +109,7 @@ static ObjectTypeCalcer* intersectionPoint( const std::vector<ObjectCalcer*>& pa
     else return 0;
   };
   if ( nlines == 2 )
-    return which == 1 ? new ObjectTypeCalcer( LineLineIntersectionType::instance(), parents ) : 0;
+    return which == -1 ? new ObjectTypeCalcer( LineLineIntersectionType::instance(), parents ) : 0;
   else if ( nlines == 1 && nconics == 1 )
   {
     std::vector<ObjectCalcer*> intparents( parents );
@@ -133,10 +137,71 @@ static ObjectTypeCalcer* intersectionPoint( const std::vector<ObjectCalcer*>& pa
   else return 0;
 }
 
+ObjectCalcer* KigFilterKSeg::transformObject( const QString& file, KigDocument& kigdoc,
+                                              std::vector<ObjectCalcer*>& parents,
+                                              int subtype, bool& ok )
+{
+  ok = true;
+  ObjectCalcer* retobj = 0;
+  switch( subtype )
+  {
+    case G_TRANSLATED:
+    {
+      std::vector<ObjectCalcer*> vectorparents( parents.begin() + 1, parents.end() );
+      ObjectTypeCalcer* vector = new ObjectTypeCalcer( VectorType::instance(), vectorparents );
+      vector->calc( kigdoc );
+
+      std::vector<ObjectCalcer*> transparents;
+      transparents.push_back( parents[0] );
+      transparents.push_back( vector );
+      retobj = new ObjectTypeCalcer( TranslatedType::instance(), transparents );
+      break;
+    }
+    case G_ROTATED:
+    {
+      std::vector<ObjectCalcer*> angleparents( parents.begin() + 2, parents.end() );
+      ObjectTypeCalcer* angle = new ObjectTypeCalcer( AngleType::instance(), angleparents );
+      angle->calc( kigdoc );
+
+      std::vector<ObjectCalcer*> rotparents;
+      rotparents.push_back( parents[0] );
+      rotparents.push_back( parents[1] );
+      rotparents.push_back( angle );
+      retobj = new ObjectTypeCalcer( RotationType::instance(), rotparents );
+      break;
+    }
+    case G_SCALED:
+    {
+      if ( parents.size() == 4 )
+      {
+        retobj = new ObjectTypeCalcer( ScalingOverCenter2Type::instance(), parents );
+      }
+      else
+      {
+        // TODO
+        notSupported( file, i18n( "This KSeg document uses a scaling "
+                                  "transformation, which Kig currently "
+                                  "cannot import." ) );
+        ok = false;
+        return 0;
+      }
+      break;
+    }
+    case G_REFLECTED:
+    {
+      std::vector<ObjectCalcer*> mirparents( parents.begin(), parents.end() );
+      retobj = new ObjectTypeCalcer( LineReflectionType::instance(), mirparents );
+      break;
+    }
+  }
+
+  return retobj;
+}
+
 KigDocument* KigFilterKSeg::load( const QString& file )
 {
   QFile ffile( file );
-  if ( ! ffile.open( IO_ReadOnly ) )
+  if ( ! ffile.open( QIODevice::ReadOnly ) )
   {
     fileNotFound( file );
     return false;
@@ -153,8 +218,8 @@ KigDocument* KigFilterKSeg::load( const QString& file )
 
   QByteArray array;
   fstream >> array;
-  QBuffer buf( array );
-  buf.open( IO_ReadOnly );
+  QBuffer buf( &array );
+  buf.open( QIODevice::ReadOnly );
   QDataStream stream( &buf );
 
   stream.setVersion( 3 );
@@ -172,6 +237,7 @@ KigDocument* KigFilterKSeg::load( const QString& file )
   };
 
   std::vector<ObjectHolder*> ret;
+  std::vector<ObjectHolder*> ret2;
 
   // G_refs
   unsigned int count;
@@ -210,7 +276,6 @@ KigDocument* KigFilterKSeg::load( const QString& file )
 
     // avoid g++ warnings about unused vars..
     // this doesn't really do anything..
-    (void) labelVisible;
     (void) given;
     (void) final;
 
@@ -232,95 +297,38 @@ KigDocument* KigFilterKSeg::load( const QString& file )
 
     // now load the object data..
     ObjectHolder* object = 0;
+    ObjectCalcer* o = 0;
+    bool ok = true;
 
-    if ( descendtype <= G_REFLECTED )
+    QColor color = style.pen.color();
+    int width = style.pen.width();
+
+/*
+    kDebug() << "type: " << type
+              << "descendtype: " << descendtype << endl
+              << "label: " << labeltext << endl;
+//*/
+
+    switch ( type )
     {
-      ObjectTypeCalcer* o = 0;
-      // this is a transformed object..
-      switch( descendtype )
-      {
-      case G_TRANSLATED:
-      {
-        std::vector<ObjectCalcer*> vectorparents( parents.begin() + 1, parents.end() );
-        ObjectTypeCalcer* vector = new ObjectTypeCalcer( VectorType::instance(), vectorparents );
-        vector->calc( *retdoc );
-
-        std::vector<ObjectCalcer*> transparents;
-        transparents.push_back( parents[0] );
-        transparents.push_back( vector );
-        o = new ObjectTypeCalcer( TranslatedType::instance(), transparents );
-        break;
-      }
-      case G_ROTATED:
-      {
-        std::vector<ObjectCalcer*> angleparents( parents.begin() + 2, parents.end() );
-        ObjectTypeCalcer* angle = new ObjectTypeCalcer( AngleType::instance(), angleparents );
-        angle->calc( *retdoc );
-
-        std::vector<ObjectCalcer*> rotparents;
-        rotparents.push_back( parents[0] );
-        rotparents.push_back( parents[1] );
-        rotparents.push_back( angle );
-        o = new ObjectTypeCalcer( RotationType::instance(), rotparents );
-        break;
-      }
-      case G_SCALED:
-      {
-        // TODO
-        notSupported( file, i18n( "This KSeg document uses a scaling "
-                                  "transformation, which Kig currently "
-                                  "cannot import." ) );
-        return false;
-        o = new ObjectTypeCalcer( ScalingOverCenterType::instance(), parents );
-        break;
-      }
-      case G_REFLECTED:
-      {
-        std::vector<ObjectCalcer*> mirparents( parents.begin(), parents.end() );
-        o = new ObjectTypeCalcer( LineReflectionType::instance(), mirparents );
-        break;
-      }
-      }
-      assert( o );
-      ObjectDrawer* d;
-      if ( type == G_POINT )
-      {
-        int width;
-        switch( style.pointstyle )
-        {
-        case SMALL_CIRCLE:
-          width = 2;
-          break;
-        case MEDIUM_CIRCLE:
-          width = 3;
-          break;
-        default:
-          width = 5;
-          break;
-        }
-        d = new ObjectDrawer( style.brush.color(), width, visible );
-      }
-      else
-      {
-        d = new ObjectDrawer( style.pen.color(), style.pen.width(), visible, style.pen.style() );
-      };
-      assert( d );
-      object = new ObjectHolder( o, d );
-    }
-    else
-      switch( type )
-      {
       case G_POINT:
       {
-        ObjectCalcer* point = 0;
         switch( descendtype )
         {
+        case G_TRANSLATED:
+        case G_ROTATED:
+        case G_SCALED:
+        case G_REFLECTED:
+        {
+          o = transformObject( file, *retdoc, parents, descendtype, ok );
+          break;
+        }
         case G_FREE_POINT:
         {
           // fixed point
           if ( nparents != 0 ) KIG_FILTER_PARSE_ERROR;
           Coordinate c = readKSegCoordinate( stream );
-          point = fact->fixedPointCalcer( c );
+          o = fact->fixedPointCalcer( c );
           break;
         }
         case G_CONSTRAINED_POINT:
@@ -328,10 +336,10 @@ KigDocument* KigFilterKSeg::load( const QString& file )
           // constrained point
           double p;
           stream >> p;
-          assert( nparents == 1 );
+          if ( nparents != 1 ) KIG_FILTER_PARSE_ERROR;
           ObjectCalcer* parent = parents[0];
           assert( parent );
-          point = fact->constrainedPointCalcer( parent, p );
+          o = fact->constrainedPointCalcer( parent, p );
           break;
         }
         case G_INTERSECTION_POINT:
@@ -340,71 +348,80 @@ KigDocument* KigFilterKSeg::load( const QString& file )
           // for all objects G_INTERSECTION_POINT gets the
           // first intersection of its parents, G_INTERSECTION2_POINT
           // represents the second, if present.
-          point = intersectionPoint( parents, 1 );
-          if ( ! point ) KIG_FILTER_PARSE_ERROR;
+          o = intersectionPoint( parents, -1 );
+          if ( ! o ) KIG_FILTER_PARSE_ERROR;
           break;
         }
         case G_INTERSECTION2_POINT:
-          point = intersectionPoint( parents, -1 );
-          if ( ! point ) KIG_FILTER_PARSE_ERROR;
+        {
+          o = intersectionPoint( parents, 1 );
+          if ( ! o ) KIG_FILTER_PARSE_ERROR;
           break;
+        }
         case G_MID_POINT:
         {
           // midpoint of a segment..
           if ( parents.size() != 1 ) KIG_FILTER_PARSE_ERROR;
           if ( !parents[0]->imp()->inherits( SegmentImp::stype() ) )
             KIG_FILTER_PARSE_ERROR;
-          int index = parents[0]->imp()->propertiesInternalNames().findIndex( "mid-point" );
-          assert( index != -1 );
-          point = new ObjectPropertyCalcer( parents[0], index );
+//          int index = parents[0]->imp()->propertiesInternalNames().indexOf( "mid-point" );
+//          assert( index != -1 );
+          o = new ObjectPropertyCalcer( parents[0], "mid-point" );
           break;
         }
         default:
           KIG_FILTER_PARSE_ERROR;
         };
-        assert( point );
-        int width = style.pointstyle == SMALL_CIRCLE ? 2 : style.pointstyle == MEDIUM_CIRCLE ? 3 : 5;
-        ObjectDrawer* d =
-          new ObjectDrawer( style.brush.color(), width, visible, style.pen.style() );
-        object = new ObjectHolder( point, d );
+        width = style.pointstyle == SMALL_CIRCLE ? 2 : style.pointstyle == MEDIUM_CIRCLE ? 3 : 5;
+        color = style.brush.color();
         break;
       };
       case G_SEGMENT:
       {
         switch( descendtype )
         {
+        case G_TRANSLATED:
+        case G_ROTATED:
+        case G_SCALED:
+        case G_REFLECTED:
+        {
+          o = transformObject( file, *retdoc, parents, descendtype, ok );
+          break;
+        }
         case G_ENDPOINTS_SEGMENT:
         {
           if ( nparents != 2 ) KIG_FILTER_PARSE_ERROR;
-          ObjectTypeCalcer* o = new ObjectTypeCalcer( SegmentABType::instance(), parents );
-          ObjectDrawer* d = new ObjectDrawer( style.pen.color(), style.pen.width(), visible, style.pen.style() );
-          object = new ObjectHolder( o, d );
+          o = new ObjectTypeCalcer( SegmentABType::instance(), parents );
           break;
         }
         default:
           KIG_FILTER_PARSE_ERROR;
-        };
+        }
         break;
       };
       case G_RAY:
       {
         switch( descendtype )
         {
+        case G_TRANSLATED:
+        case G_ROTATED:
+        case G_SCALED:
+        case G_REFLECTED:
+        {
+          o = transformObject( file, *retdoc, parents, descendtype, ok );
+          break;
+        }
         case G_TWOPOINTS_RAY:
         {
           if ( nparents != 2 ) KIG_FILTER_PARSE_ERROR;
-          ObjectTypeCalcer* o = new ObjectTypeCalcer( RayABType::instance(), parents );
-          ObjectDrawer* d = new ObjectDrawer( style.pen.color(), style.pen.width(), visible, style.pen.style() );
-          object = new ObjectHolder( o, d );
+          o = new ObjectTypeCalcer( RayABType::instance(), parents );
           break;
         }
         case G_BISECTOR_RAY:
         {
           ObjectTypeCalcer* angle = new ObjectTypeCalcer( HalfAngleType::instance(), parents );
           angle->calc( *retdoc );
-          ObjectPropertyCalcer* o = fact->propertyObjectCalcer( angle, "angle-bisector" );
-          ObjectDrawer* d = new ObjectDrawer( style.pen.color(), style.pen.width(), visible, style.pen.style() );
-          object = new ObjectHolder( o, d );
+          o = fact->propertyObjectCalcer( angle, "angle-bisector" );
           break;
         }
         default:
@@ -414,32 +431,51 @@ KigDocument* KigFilterKSeg::load( const QString& file )
       };
       case G_LINE:
       {
-        if ( nparents != 2 ) KIG_FILTER_PARSE_ERROR;
-        ObjectTypeCalcer* o = 0;
         switch( descendtype )
         {
+        case G_TRANSLATED:
+        case G_ROTATED:
+        case G_SCALED:
+        case G_REFLECTED:
+        {
+          o = transformObject( file, *retdoc, parents, descendtype, ok );
+          break;
+        }
         case G_TWOPOINTS_LINE:
+        {
+          if ( nparents != 2 ) KIG_FILTER_PARSE_ERROR;
           o = new ObjectTypeCalcer( LineABType::instance(), parents );
           break;
+        }
         case G_PARALLEL_LINE:
+        {
+          if ( nparents != 2 ) KIG_FILTER_PARSE_ERROR;
           o = new ObjectTypeCalcer( LineParallelLPType::instance(), parents );
           break;
+        }
         case G_PERPENDICULAR_LINE:
+        {
+          if ( nparents != 2 ) KIG_FILTER_PARSE_ERROR;
           o = new ObjectTypeCalcer( LinePerpendLPType::instance(), parents );
           break;
+        }
         default:
           KIG_FILTER_PARSE_ERROR;
         };
-        assert( o );
-        ObjectDrawer* d = new ObjectDrawer( style.pen.color(), style.pen.width(), visible, style.pen.style() );
-        object = new ObjectHolder( o, d );
         break;
       };
       case G_CIRCLE:
       {
-        ObjectTypeCalcer* o = 0;
         switch( descendtype )
         {
+        case G_TRANSLATED:
+        case G_ROTATED:
+        case G_SCALED:
+        case G_REFLECTED:
+        {
+          o = transformObject( file, *retdoc, parents, descendtype, ok );
+          break;
+        }
         case G_CENTERPOINT_CIRCLE:
         {
           if ( nparents != 2 ) KIG_FILTER_PARSE_ERROR;
@@ -460,9 +496,10 @@ KigDocument* KigFilterKSeg::load( const QString& file )
             point = parents[1];
             segment = parents[0];
           };
-          int index = segment->imp()->propertiesInternalNames().findIndex( "length" );
+          int index = segment->imp()->propertiesInternalNames().indexOf( "length" );
           if ( index == -1 ) KIG_FILTER_PARSE_ERROR;
-          ObjectPropertyCalcer* length = new ObjectPropertyCalcer( segment, index );
+          ObjectPropertyCalcer* length = new ObjectPropertyCalcer( segment, "length" );
+          length->calc( *retdoc );
           std::vector<ObjectCalcer*> cparents;
           cparents.push_back( point );
           cparents.push_back( length );
@@ -472,25 +509,51 @@ KigDocument* KigFilterKSeg::load( const QString& file )
         default:
           KIG_FILTER_PARSE_ERROR;
         };
-        assert( o );
-        ObjectDrawer* d = new ObjectDrawer( style.pen.color(), style.pen.width(), visible, style.pen.style() );
-        object = new ObjectHolder( o, d );
         break;
       };
       case G_ARC:
       {
-        if ( nparents != 3 ) KIG_FILTER_PARSE_ERROR;
-        ObjectTypeCalcer* o = new ObjectTypeCalcer( ArcBTPType::instance(), parents );
-        ObjectDrawer* d = new ObjectDrawer( style.pen.color(), style.pen.width(), visible, style.pen.style() );
-        object = new ObjectHolder( o, d );
+        switch( descendtype )
+        {
+        case G_TRANSLATED:
+        case G_ROTATED:
+        case G_SCALED:
+        case G_REFLECTED:
+        {
+          o = transformObject( file, *retdoc, parents, descendtype, ok );
+          break;
+        }
+        case G_THREEPOINTS_ARC:
+        {
+          if ( nparents != 3 ) KIG_FILTER_PARSE_ERROR;
+          o = new ObjectTypeCalcer( ArcBTPType::instance(), parents );
+          break;
+        }
+        default:
+          KIG_FILTER_PARSE_ERROR;
+        }
         break;
       };
       case G_POLYGON:
       {
-        if ( nparents < 3 ) KIG_FILTER_PARSE_ERROR;
-        ObjectTypeCalcer* o = new ObjectTypeCalcer( PolygonBNPType::instance(), parents );
-        ObjectDrawer* d = new ObjectDrawer( style.pen.color(), style.pen.width(), visible, style.pen.style() );
-        object = new ObjectHolder( o, d );
+        switch( descendtype )
+        {
+        case G_TRANSLATED:
+        case G_ROTATED:
+        case G_SCALED:
+        case G_REFLECTED:
+        {
+          o = transformObject( file, *retdoc, parents, descendtype, ok );
+          break;
+        }
+        default:
+        {
+          if ( nparents < 3 ) KIG_FILTER_PARSE_ERROR;
+          o = new ObjectTypeCalcer( PolygonBNPType::instance(), parents );
+        }
+        }
+//        default:
+//          KIG_FILTER_PARSE_ERROR;
         break;
       };
       case G_CIRCLEINTERIOR:
@@ -513,24 +576,147 @@ KigDocument* KigFilterKSeg::load( const QString& file )
       };
       case G_LOCUS:
       {
-        if ( nparents != 2 ) KIG_FILTER_PARSE_ERROR;
-        ObjectTypeCalcer* o = fact->locusCalcer( parents[0], parents[1] );
-        ObjectDrawer* d = new ObjectDrawer( style.pen.color(), style.pen.width(), visible, style.pen.style() );
-        object = new ObjectHolder( o, d );
+        switch( descendtype )
+        {
+        case G_TRANSLATED:
+        case G_ROTATED:
+        case G_SCALED:
+        case G_REFLECTED:
+        {
+          o = transformObject( file, *retdoc, parents, descendtype, ok );
+          break;
+        }
+        case G_OBJECT_LOCUS:
+        {
+          if ( nparents != 2 ) KIG_FILTER_PARSE_ERROR;
+          o = fact->locusCalcer( parents[0], parents[1] );
+          break;
+        }
+        default:
+          KIG_FILTER_PARSE_ERROR;
+        }
         break;
       };
       case G_MEASURE:
-        KIG_FILTER_PARSE_ERROR;
+      {
+        QByteArray prop;
+        Coordinate txtcoords = readKSegCoordinate( stream );
+        switch( descendtype )
+        {
+        case G_DISTANCE_MEASURE:
+        {
+          if ( nparents != 2 ) KIG_FILTER_PARSE_ERROR;
+          ObjectCalcer* c =
+            new ObjectTypeCalcer( SegmentABType::instance(), parents );
+          c->calc( *retdoc );
+          parents.clear();
+          parents.push_back( c );
+          prop = "length";
+          break;
+        }
+        case G_LENGTH_MEASURE:
+        {
+          if ( nparents != 1 ) KIG_FILTER_PARSE_ERROR;
+          if ( parents[0]->imp()->inherits( SegmentImp::stype() ) )
+            prop = "length";
+          else if ( parents[0]->imp()->inherits( CircleImp::stype() ) )
+            prop = "circumference";
+          else KIG_FILTER_PARSE_ERROR;
+          break;
+        }
+        case G_RADIUS_MEASURE:
+        {
+          if ( nparents != 1 ) KIG_FILTER_PARSE_ERROR;
+          if ( !parents[0]->imp()->inherits( CircleImp::stype() ) )
+            KIG_FILTER_PARSE_ERROR;
+          prop = "radius";
+          break;
+        }
+        case G_ANGLE_MEASURE:
+        {
+          if ( nparents != 3 ) KIG_FILTER_PARSE_ERROR;
+          ObjectTypeCalcer* ao =
+            new ObjectTypeCalcer( AngleType::instance(), parents );
+          ao->calc( *retdoc );
+          parents.clear();
+          parents.push_back( ao );
+          prop = "angle-degrees";
+          break;
+        }
+//        case G_RATIO_MEASURE: // TODO
+        case G_SLOPE_MEASURE:
+        {
+          if ( nparents != 1 ) KIG_FILTER_PARSE_ERROR;
+          if ( !parents[0]->imp()->inherits( AbstractLineImp::stype() ) )
+            KIG_FILTER_PARSE_ERROR;
+          prop = "slope";
+          break;
+        }
+        case G_AREA_MEASURE:
+        {
+          if ( nparents != 1 ) KIG_FILTER_PARSE_ERROR;
+          if ( parents[0]->imp()->inherits( PolygonImp::stype() )
+               || parents[0]->imp()->inherits( PolygonImp::stype3() )
+               || parents[0]->imp()->inherits( PolygonImp::stype4() ) )
+            prop = "polygon-surface";
+          else KIG_FILTER_PARSE_ERROR;
+          break;
+        }
+        default:
+          KIG_FILTER_PARSE_ERROR;
+        }
+        if ( parents.size() != 1 ) KIG_FILTER_PARSE_ERROR;
+        o = filtersConstructTextObject(
+                txtcoords, parents[0], prop, *retdoc, false );
+        break;
+      }
       case G_CALCULATE:
         KIG_FILTER_PARSE_ERROR;
       case G_ANNOTATION:
         KIG_FILTER_PARSE_ERROR;
       case G_LOOP:
         KIG_FILTER_PARSE_ERROR;
-      };
+      default:
+        KIG_FILTER_PARSE_ERROR;
+
+    }
+
+    // checking if the object was correctly created
+    if ( ! o )
+    {
+      if ( ok )
+        KIG_FILTER_PARSE_ERROR
+      else
+        return 0;
+    }
+
+    ObjectDrawer* d = new ObjectDrawer( color, width, visible, style.pen.style() );
+    if ( !labeltext.isEmpty() )
+    {
+      ObjectConstCalcer* name = new ObjectConstCalcer( new StringImp( labeltext ) );
+      object = new ObjectHolder( o, d, name );
+    }
+    else
+    {
+      object = new ObjectHolder( o, d );
+    }
+
     assert( object );
     ret[i] = object;
     object->calc( *retdoc );
+    if ( !labeltext.isEmpty() && labelVisible && object->imp()->inherits( PointImp::stype() ) )
+    {
+      std::vector<ObjectCalcer*> args2;
+      args2.push_back( object->nameCalcer() );
+      ObjectCalcer* oc2 = fact->attachedLabelCalcer(
+               QString::fromLatin1( "%1" ), object->calcer(),
+               static_cast<const PointImp*>( object->imp() )->coordinate(),
+               false, args2, *retdoc );
+      oc2->calc( *retdoc );
+      ObjectDrawer* d2 = new ObjectDrawer( style.pen.color() );
+      ObjectHolder* o2 = new ObjectHolder( oc2, d2 );
+      ret2.push_back( o2 );
+    }
   };
 
   // selection groups ( we ignore them, but we pretend to read them
@@ -553,6 +739,7 @@ KigDocument* KigFilterKSeg::load( const QString& file )
 
   // no more data in the file..
   retdoc->addObjects( ret );
+  retdoc->addObjects( ret2 );
   retdoc->setAxes( false );
   retdoc->setGrid( false );
   return retdoc;
