@@ -29,7 +29,7 @@
 
 #include "ksutils.h"
 #include "Options.h"
-#include "starobject.h"
+#include "skyobjects/starobject.h"
 
 ColorScheme::ColorScheme() : FileName() {
     //Each color has two names associated with it.  The KeyName is its
@@ -143,8 +143,7 @@ void ColorScheme::copy( const ColorScheme &cs ) {
     KeyName = cs.KeyName;
     Name = cs.Name;
     Default = cs.Default;
-    setStarColorMode( cs.StarColorMode );
-    setStarColorIntensity( cs.StarColorIntensity );
+    setStarColorModeIntensity( cs.StarColorMode, cs.StarColorIntensity );
     Palette = cs.Palette;
     FileName = cs.FileName;
 }
@@ -195,7 +194,7 @@ bool ColorScheme::load( const QString &name ) {
     if ( name == i18nc("use 'night vision' color scheme", "Night Vision") ) filename = "night.colors";
 
     //Try the filename if it ends with ".colors"
-    if ( filename.endsWith( ".colors" ) )
+    if ( filename.endsWith( QLatin1String( ".colors" ) ) )
         ok = KSUtils::openDataFile( file, filename );
 
     //If that didn't work, try assuming that 'name' is the color scheme name
@@ -259,8 +258,8 @@ bool ColorScheme::load( const QString &name ) {
             //Assuming the old *.colors format.  Loop through the KeyName list,
             //and assign each color.  Note that order matters here, but only here
             //(so if you don't use the old format, then order doesn't ever matter)
-            QStringList::Iterator it = KeyName.begin();
-            QStringList::Iterator it_end = KeyName.end();
+            QStringList::ConstIterator it = KeyName.constBegin();
+            QStringList::ConstIterator it_end = KeyName.constEnd();
             for ( ; it != it_end; ++it )
                 setColor( QString(*it), line.left( 7 ) );
         }
@@ -327,8 +326,7 @@ void ColorScheme::loadFromConfig() {
     for ( int i=0; i < KeyName.size(); ++i )
         setColor( KeyName.at(i), cg.readEntry( KeyName.at(i).toUtf8().constData(), Default.at( i ) ) );
 
-    setStarColorMode( cg.readEntry( "StarColorMode", 0 ) );
-    setStarColorIntensity( cg.readEntry( "StarColorIntensity", 5 ) );
+    setStarColorModeIntensity( cg.readEntry( "StarColorMode", 0 ), cg.readEntry( "StarColorIntensity", 5 ) );
 }
 
 void ColorScheme::saveToConfig() {
@@ -353,3 +351,11 @@ void ColorScheme::setStarColorIntensity( int intens ) {
     Options::setStarColorIntensity( intens );
     StarObject::initImages();
 }
+
+void ColorScheme::setStarColorModeIntensity( int mode, int intens) {
+    StarColorMode = mode;
+    StarColorIntensity = intens;
+    Options::setStarColorMode( mode );
+    Options::setStarColorIntensity( intens );
+    StarObject::initImages();
+}
