@@ -22,21 +22,47 @@
 
 #include "kstars.h"
 #include "kstarsdata.h"
-#include "starobject.h"
-#include "ksmoon.h"
-#include "skyobject.h"
-#include "trailobject.h"
+#include "skyobjects/starobject.h"
+#include "skyobjects/ksmoon.h"
+#include "skyobjects/skyobject.h"
+#include "skyobjects/trailobject.h"
 #include "skymap.h"
 
-#include "indimenu.h"
-#include "devicemanager.h"
-#include "indidevice.h"
-#include "indigroup.h"
-#include "indiproperty.h"
+#include <config-kstars.h>
+
+#ifdef HAVE_INDI_H
+#include "indi/indimenu.h"
+#include "indi/devicemanager.h"
+#include "indi/indidevice.h"
+#include "indi/indigroup.h"
+#include "indi/indiproperty.h"
+#endif
+
 #include "skycomponents/constellationboundary.h"
 
 #include <kactioncollection.h>
 
+// Convert magnitude to string representation for QLabel
+static QString magToStr(double m) {
+	return QString("%1<sup>m</sup>").arg(m, 0, 'f', 2);
+}
+
+// Helper function to return object name
+static QString getObjectName(SkyObject *obj) {
+	// FIXME: make logic less convoluted. 
+	QString name;
+	if( obj->longname() != obj->name() ) { // Object has proper name
+		name = obj->translatedLongName() + ", " + obj->translatedName();
+	} else {
+		if( ! obj->translatedName2().isEmpty() ) {
+			name = obj->translatedName() + ", " + obj->translatedName2();
+		} else {
+			name = obj->translatedName();
+		}
+	}
+	return name;
+}
+
 KSPopupMenu::KSPopupMenu( KStars *_ks )
         : KMenu( _ks ), ks(_ks)
 {}
@@ -69,59 +95,75 @@ KSPopupMenu::~KSPopupMenu()
 void KSPopupMenu::createEmptyMenu( SkyObject *nullObj ) {
     initPopupMenu( nullObj, i18n( "Empty sky" ), QString(), QString(), true, true, false, false, false, true, false );
 
-    addAction( i18nc( "First Generation Digitized Sky Survey", "Show 1st-Gen DSS Image" ), ks->map(), SLOT( slotDSS() ) );
-    addAction( i18nc( "Second Generation Digitized Sky Survey", "Show 2nd-Gen DSS Image" ), ks->map(), SLOT( slotDSS2() ) );
+    addAction( i18nc( "Sloan Digital Sky Survey", "Show SDSS Image" ), ks->map(), SLOT( slotSDSS() ) );
+    addAction( i18nc( "Digitized Sky Survey", "Show DSS Image" ), ks->map(), SLOT( slotDSS() ) );
 }
 
 void KSPopupMenu::createStarMenu( StarObject *star ) {
     //Add name, rise/set time, center/track, and detail-window items
-    initPopupMenu( star, star->translatedLongName(), i18n( "Spectral type: %1" , star->sptype()),
-                   i18n( "star" ) );
-
+	QString name;
+	if( star->name() != "star" ) {
+		name = star->translatedLongName();
+	} else {
+		if( star->getHDIndex() ) {
+			name = QString( "HD%1" ).arg( QString::number( star->getHDIndex() ) );
+		} else {
+			// FIXME: this should be some catalog name too
+			name = "Star";
+		}
+	}
+    initPopupMenu( star, name, i18n( "star" ), i18n("%1<sup>m</sup>, %2", star->mag(), star->sptype()) );
     //If the star is named, add custom items to popup menu based on object's ImageList and InfoList
     if ( star->name() != "star" ) {
         addLinksToMenu( star );
     } else {
-        addAction( i18nc( "First Generation Digitized Sky Survey", "Show 1st-Gen DSS Image" ), ks->map(), SLOT( slotDSS() ) );
-        addAction( i18nc( "Second Generation Digitized Sky Survey", "Show 2nd-Gen DSS Image" ), ks->map(), SLOT( slotDSS2() ) );
+        addAction( i18nc( "Sloan Digital Sky Survey", "Show SDSS Image" ), ks->map(), SLOT( slotSDSS() ) );
+        addAction( i18nc( "Digitized Sky Survey", "Show DSS Image" ), ks->map(), SLOT( slotDSS() ) );
     }
 }
-
+ 
 void KSPopupMenu::createDeepSkyObjectMenu( SkyObject *obj ) {
-    QString TypeName = ks->data()->typeName( obj->type() );
-    QString secondName = obj->translatedName2();
-    if ( obj->longname() != obj->name() ) secondName = obj->translatedLongName();
-
-    initPopupMenu( obj, obj->translatedName(), secondName, TypeName );
+	QString name = getObjectName(obj);
+    QString typeName = ks->data()->typeName( obj->type() );
+	// FIXME: information about angular sizes should be added.
+	// Requires downcast. Not sure whether it safe.
+	QString info = magToStr( obj->mag() );
+	
+	initPopupMenu( obj, name, typeName, info );
     addLinksToMenu( obj );
 }
 
 void KSPopupMenu::createCustomObjectMenu( SkyObject *obj ) {
-    QString TypeName = ks->data()->typeName( obj->type() );
-    QString secondName = obj->translatedName2();
-    if ( obj->longname() != obj->name() ) secondName = obj->translatedLongName();
-
-    initPopupMenu( obj, obj->translatedName(), secondName, TypeName );
+	QString name = getObjectName(obj); 
+    QString typeName = ks->data()->typeName( obj->type() );
+	QString info = magToStr( obj->mag() );
+	
+    initPopupMenu( obj, name, typeName, info );
 
     addLinksToMenu( obj, true );
 }
 
 void KSPopupMenu::createPlanetMenu( SkyObject *p ) {
     bool addTrail( ! ((TrailObject*)p)->hasTrail() );
-    QString oname;
+    QString info;
+	QString type;
     if ( p->name() == "Moon" ) {
-        oname = ((KSMoon *)p)->phaseName();
-    }
-    initPopupMenu( p, p->translatedName(), oname, i18n("Solar System"), true, true, true, true, addTrail );
+        info = QString("%1<sup>m</sup>, %2").arg(p->mag(), 0, 'f', 2).arg(((KSMoon *)p)->phaseName());
+    } else {
+		// FIXME: angular size is required.
+		info = magToStr( p->mag() );
+		type = i18n("Solar system object");
+	}
+    initPopupMenu( p, p->translatedName(), type, info, true, true, true, true, addTrail );
     addLinksToMenu( p, false ); //don't offer DSS images for planets
 }
 
-void KSPopupMenu::initPopupMenu( SkyObject *obj, const QString &_s1, const QString &s2, const QString &s3,
+void KSPopupMenu::initPopupMenu( SkyObject *obj, const QString &name, const QString &type, const QString &info,
                                  bool showRiseSet, bool showCenterTrack, bool showDetails, bool showTrail, bool addTrail,
                                  bool showAngularDistance, bool showObsList ) {
 
     clear();
-    QString s1 = _s1;
+    QString s1 = name;
     if ( s1.isEmpty() ) s1 = i18n( "Empty sky" );
 
     bool showLabel( true );
@@ -134,8 +176,8 @@ void KSPopupMenu::initPopupMenu( SkyObject *obj, const QString &_s1, const QStri
     aName->setDefaultWidget( labName );
     addAction( aName );
 
-    if ( ! s2.isEmpty() ) {
-        labName2 = new QLabel( "<b>"+s2+"</b>", this );
+    if ( ! type.isEmpty() ) {
+        labName2 = new QLabel( "<b>"+type+"</b>", this );
         labName2->setAlignment( Qt::AlignHCenter | Qt::AlignVCenter );
         aName2 = new KAction( this );
         ks->actionCollection()->addAction( "title_name2", aName2 );
@@ -143,8 +185,8 @@ void KSPopupMenu::initPopupMenu( SkyObject *obj, const QString &_s1, const QStri
         addAction( aName2 );
     }
 
-    if ( ! s3.isEmpty() ) {
-        labType = new QLabel( "<b>"+s3+"</b>", this );
+    if ( ! info.isEmpty() ) {
+        labType = new QLabel( "<b>"+info+"</b>", this );
         labType->setAlignment( Qt::AlignHCenter | Qt::AlignVCenter );
         aType = new KAction( this );
         ks->actionCollection()->addAction( "title_type", aType );
@@ -248,17 +290,31 @@ void KSPopupMenu::initPopupMenu( SkyObject *obj, const QString &_s1, const QStri
 
     addSeparator();
 
+#ifdef HAVE_XPLANET
+    if ( obj->isSolarSystem() && obj->type() != SkyObject::COMET ) {
+        QMenu *xplanetSubmenu = new QMenu();
+        xplanetSubmenu->setTitle( i18n( "Print Xplanet view" ) );
+        xplanetSubmenu->addAction( i18n( "To screen" ), ks->map(), SLOT( slotXplanetToScreen() ) );
+        xplanetSubmenu->addAction( i18n( "To file..." ), ks->map(), SLOT( slotXplanetToFile() ) );
+        addMenu( xplanetSubmenu );
+    }
+#endif
+
+    addSeparator();
+
+    #ifdef HAVE_INDI_H
     if (addINDI())
         addSeparator();
+    #endif
 }
 
 void KSPopupMenu::addLinksToMenu( SkyObject *obj, bool showDSS ) {
     QString sURL;
-    QStringList::Iterator itList, itTitle, itListEnd;
+    QStringList::ConstIterator itList, itTitle, itListEnd;
 
-    itList  = obj->ImageList.begin();
-    itTitle = obj->ImageTitle.begin();
-    itListEnd = obj->ImageList.end();
+    itList  = obj->ImageList().constBegin();
+    itTitle = obj->ImageTitle().constBegin();
+    itListEnd = obj->ImageList().constEnd();
 
     int id = 100;
     for ( ; itList != itListEnd; ++itList ) {
@@ -269,15 +325,15 @@ void KSPopupMenu::addLinksToMenu( SkyObject *obj, bool showDSS ) {
     }
 
     if ( showDSS ) {
-        addAction( i18nc( "First Generation Digitized Sky Survey", "Show 1st-Gen DSS Image" ), ks->map(), SLOT( slotDSS() ) );
-        addAction( i18nc( "Second Generation Digitized Sky Survey", "Show 2nd-Gen DSS Image" ), ks->map(), SLOT( slotDSS2() ) );
+        addAction( i18nc( "Sloan Digital Sky Survey", "Show SDSS Image" ), ks->map(), SLOT( slotSDSS() ) );
+        addAction( i18nc( "Digitized Sky Survey", "Show DSS Image" ), ks->map(), SLOT( slotDSS() ) );
         addSeparator();
     }
-    else if ( obj->ImageList.count() ) addSeparator();
+    else if ( obj->ImageList().count() ) addSeparator();
 
-    itList  = obj->InfoList.begin();
-    itTitle = obj->InfoTitle.begin();
-    itListEnd = obj->InfoList.end();
+    itList  = obj->InfoList().constBegin();
+    itTitle = obj->InfoTitle().constBegin();
+    itListEnd = obj->InfoList().constEnd();
 
     id = 200;
     for ( ; itList != itListEnd; ++itList ) {
@@ -290,7 +346,8 @@ void KSPopupMenu::addLinksToMenu( SkyObject *obj, bool showDSS ) {
 
 bool KSPopupMenu::addINDI(void)
 {
-    INDIMenu *indiMenu = ks->getINDIMenu();
+    #ifdef HAVE_INDI_H
+    INDIMenu *indiMenu = ks->indiMenu();
     DeviceManager *managers;
     INDI_D *dev;
     INDI_G *grp;
@@ -366,6 +423,9 @@ bool KSPopupMenu::addINDI(void)
     } // end device manager
 
     return true;
+    #else
+    return false;
+    #endif
 }
 
 void KSPopupMenu::setRiseSetLabels( SkyObject *obj ) {
