@@ -35,15 +35,21 @@
 #include "ksutils.h"
 #include "ksfilereader.h"
 #include "ksnumbers.h"
-#include "skypoint.h"
-#include "skyobject.h"
+#include "skyobjects/skypoint.h"
+#include "skyobjects/skyobject.h"
 
 #include "simclock.h"
 #include "timezonerule.h"
-#include "indidriver.h"
-#include "indi/libs/lilxml.h"
-#include "indistd.h"
-#include "detaildialog.h"
+
+#include <config-kstars.h>
+
+#ifdef HAVE_INDI_H
+#include "indi/indidriver.h"
+#include "lilxml.h"
+#include "indi/indistd.h"
+#endif
+
+#include "dialogs/detaildialog.h"
 
 //Initialize static members
 QList<GeoLocation*> KStarsData::geoList = QList<GeoLocation*>();
@@ -76,7 +82,7 @@ KStarsData::KStarsData(KStars* kstars) : locale(0),
     objects++;
 
     TypeName[0] = i18n( "star" );
-    TypeName[1] = i18n( "multiple star" );
+    TypeName[1] = i18n( "star" );
     TypeName[2] = i18n( "planet" );
     TypeName[3] = i18n( "open cluster" );
     TypeName[4] = i18n( "globular cluster" );
@@ -87,6 +93,12 @@ KStarsData::KStarsData(KStars* kstars) : locale(0),
     TypeName[9] = i18n( "comet" );
     TypeName[10] = i18n( "asteroid" );
     TypeName[11] = i18n( "constellation" );
+    TypeName[12] = i18n( "Moon" );
+    TypeName[13] = i18n( "asterism" );
+    TypeName[14] = i18n( "galaxy cluster" );
+    TypeName[15] = i18n( "dark nebula" );
+    TypeName[16] = i18n( "quasar" );
+    TypeName[17] = i18n( "multiple star" );
 
     //standard directories and locale objects
     locale = new KLocale( "kstars" );
@@ -584,7 +596,7 @@ bool KStarsData::readTimeZoneRulebook( void ) {
         while ( !stream.atEnd() ) {
             QString line = stream.readLine().trimmed();
             if ( line.length() && !line.startsWith('#') ) { //ignore commented and blank lines
-                QStringList fields = line.split( " ", QString::SkipEmptyParts );
+                QStringList fields = line.split( ' ', QString::SkipEmptyParts );
                 id = fields[0];
                 QTime stime = QTime( fields[3].left( fields[3].indexOf(':')).toInt() ,
                                      fields[3].mid( fields[3].indexOf(':')+1, fields[3].length()).toInt() );
@@ -692,7 +704,7 @@ bool KStarsData::openUrlFile(const QString &urlfile, QFile & file) {
                     QTextStream writeStream(&localeFile);
                     while ( ! readStream.atEnd() ) {
                         QString line = readStream.readLine();
-                        if ( !line.startsWith("XXX:") ) //do not write "deleted" lines
+                        if ( !line.startsWith( QLatin1String( "XXX:" ) ) ) //do not write "deleted" lines
                             writeStream << line << endl;
                     }
 
@@ -725,18 +737,24 @@ bool KStarsData::readURLData( const QString &urlfile, int type, bool deepOnly )
             idx = sub.indexOf(':');
             QString title = sub.left( idx );
             QString url = sub.mid( idx + 1 );
-            SkyObject *o = skyComposite()->findByName(name);
+            // Dirty hack to fix things up for planets
+            SkyObject *o;
+            if( name == "Mercury" || name == "Venus" || name == "Mars" || name == "Jupiter"
+                || name == "Saturn" || name == "Uranus" || name == "Neptune" || name == "Pluto" )
+                o = skyComposite()->findByName( i18n( name.toLocal8Bit().data() ) );
+            else
+                o = skyComposite()->findByName( name );
 
             if ( !o ) {
                 kWarning() << i18n( "Object named %1 not found", name ) ;
             } else {
                 if ( ! deepOnly || ( o->type() > 2 && o->type() < 9 ) ) {
                     if ( type==0 ) { //image URL
-                        o->ImageList.append( url );
-                        o->ImageTitle.append( title );
+                        o->ImageList().append( url );
+                        o->ImageTitle().append( title );
                     } else if ( type==1 ) { //info URL
-                        o->InfoList.append( url );
-                        o->InfoTitle.append( title );
+                        o->InfoList().append( url );
+                        o->InfoTitle().append( title );
                     }
                 }
             }
@@ -778,7 +796,7 @@ bool KStarsData::readUserLog(void)
         if ( !o ) {
             kWarning() << name << " not found" ;
         } else {
-            o->userLog = data;
+            o->userLog() = data;
         }
 
     } // end while
@@ -905,6 +923,7 @@ bool KStarsData::readVARData(void)
 
 bool KStarsData::readINDIHosts(void)
 {
+#ifdef HAVE_INDI_H
     QString indiFile("indihosts.xml");
     QFile localeFile;
     QFile file;
@@ -966,6 +985,9 @@ bool KStarsData::readINDIHosts(void)
     delLilXML(xmlParser);
 
     return true;
+    #else
+    return false;
+    #endif
 }
 
 //There's a lot of code duplication here, but it's not avoidable because 
@@ -985,10 +1007,10 @@ bool KStarsData::executeScript( const QString &scriptname, SkyMap *map ) {
     QTextStream istream(&f);
     while ( ! istream.atEnd() ) {
         QString line = istream.readLine();
-        line.replace( "string:", "" );
-        line.replace( "int:", "" );
-        line.replace( "double:", "" );
-        line.replace( "bool:", "");
+        line.remove( "string:" );
+        line.remove( "int:" );
+        line.remove( "double:" );
+        line.remove( "bool:" );
 
         //find a dbus line and extract the function name and its arguments
         //The function name starts after the last occurrence of "org.kde.kstars."
@@ -1078,7 +1100,7 @@ bool KStarsData::executeScript( const QString &scriptname, SkyMap *map ) {
 
             } else if ( fn[0] == "loadColorScheme" ) {
                 fn.removeAll( fn.first() );
-                QString csName = fn.join(" ").replace('\"', "");
+                QString csName = fn.join(" ").remove( '\"' );
                 kDebug() << "Color scheme: " << csName << endl;
 
                 QString filename = csName.toLower().trimmed();
@@ -1090,7 +1112,7 @@ bool KStarsData::executeScript( const QString &scriptname, SkyMap *map ) {
                 if ( csName == i18nc("use 'night vision' color scheme", "Night Vision") ) filename = "night.colors";
 
                 //Try the filename if it ends with ".colors"
-                if ( filename.endsWith( ".colors" ) )
+                if ( filename.endsWith( QLatin1String( ".colors" ) ) )
                     ok = colorScheme()->load( filename );
 
                 //If that didn't work, try assuming that 'name' is the color scheme name
@@ -1165,7 +1187,8 @@ bool KStarsData::executeScript( const QString &scriptname, SkyMap *map ) {
                 double dVal = fn[2].toDouble( &dOk );
 
                 if ( fn[1] == "FOVName"                ) { Options::setFOVName(       fn[2] ); cmdCount++; }
-                if ( fn[1] == "FOVSize"         && dOk ) { Options::setFOVSize( (float)dVal ); cmdCount++; }
+                if ( fn[1] == "FOVSizeX"         && dOk ) { Options::setFOVSizeX( (float)dVal ); cmdCount++; }
+                if ( fn[1] == "FOVSizeY"         && dOk ) { Options::setFOVSizeY( (float)dVal ); cmdCount++; }
                 if ( fn[1] == "FOVShape"        && nOk ) { Options::setFOVShape(       nVal ); cmdCount++; }
                 if ( fn[1] == "FOVColor"               ) { Options::setFOVColor(      fn[2] ); cmdCount++; }
                 if ( fn[1] == "ShowStars"         && bOk ) { Options::setShowStars(    bVal ); cmdCount++; }
@@ -1210,8 +1233,9 @@ bool KStarsData::executeScript( const QString &scriptname, SkyMap *map ) {
                 if ( fn[1] == "FadePlanetTrails" && bOk ) { Options::setFadePlanetTrails( bVal ); cmdCount++; }
                 if ( fn[1] == "SlewTimeScale"    && dOk ) { Options::setSlewTimeScale(    dVal ); cmdCount++; }
                 if ( fn[1] == "ZoomFactor"       && dOk ) { Options::setZoomFactor(       dVal ); cmdCount++; }
-                if ( fn[1] == "MagLimitDrawStar"     && dOk ) { Options::setMagLimitDrawStar( dVal ); cmdCount++; }
-                if ( fn[1] == "MagLimitDrawStarZoomOut" && dOk ) { Options::setMagLimitDrawStarZoomOut( dVal ); cmdCount++; }
+                //                if ( fn[1] == "MagLimitDrawStar"     && dOk ) { Options::setMagLimitDrawStar( dVal ); cmdCount++; }
+                if ( fn[1] == "StarDensity"         && dOk ) { Options::setStarDensity( dVal ); cmdCount++; }
+                //                if ( fn[1] == "MagLimitDrawStarZoomOut" && dOk ) { Options::setMagLimitDrawStarZoomOut( dVal ); cmdCount++; }
                 if ( fn[1] == "MagLimitDrawDeepSky"     && dOk ) { Options::setMagLimitDrawDeepSky( dVal ); cmdCount++; }
                 if ( fn[1] == "MagLimitDrawDeepSkyZoomOut" && dOk ) { Options::setMagLimitDrawDeepSkyZoomOut( dVal ); cmdCount++; }
                 if ( fn[1] == "StarLabelDensity" && dOk ) { Options::setStarLabelDensity( dVal ); cmdCount++; }
