@@ -26,7 +26,7 @@
 
 #include "kstarsdata.h"
 #include "skymap.h"
-#include "skypoint.h"
+#include "skyobjects/skypoint.h"
 #include "dms.h"
 #include "Options.h"
 #include "ksfilereader.h"
