@@ -23,9 +23,9 @@
 #include "Options.h"
 #include "kstarsdata.h"
 #include "skymap.h"
-#include "starobject.h"
-#include "deepskyobject.h"
-#include "ksplanet.h"
+#include "skyobjects/starobject.h"
+#include "skyobjects/deepskyobject.h"
+#include "skyobjects/ksplanet.h"
 
 #include "constellationboundary.h"
 #include "constellationboundarylines.h"
@@ -39,12 +39,14 @@
 #include "ecliptic.h"
 #include "horizoncomponent.h"
 #include "jupitermoonscomponent.h"
+#include "saturnmoonscomponent.h"
 #include "milkyway.h"
 #include "magellanicclouds.h"
 #include "solarsystemcomposite.h"
 #include "starcomponent.h"
 #include "deepstarcomponent.h"
 #include "satellitecomposite.h"
+#include "flagcomponent.h"
 
 #include "skymesh.h"
 #include "skylabeler.h"
@@ -68,7 +70,7 @@ SkyMapComposite::SkyMapComposite(SkyComponent *parent, KStarsData *data) :
     m_MagellanicClouds = new MagellanicClouds( this );
     addComponent( m_MagellanicClouds );
     //Stars must come before constellation lines
-    m_Stars = new StarComponent( this );
+    m_Stars = StarComponent::Create( this );
     addComponent( m_Stars );
 
     m_CoordinateGrid = new CoordinateGrid( this );
@@ -114,6 +116,9 @@ SkyMapComposite::SkyMapComposite(SkyComponent *parent, KStarsData *data) :
     m_SolarSystem = new SolarSystemComposite( this, data );
     addComponent( m_SolarSystem );
 
+    m_Flags = new FlagComponent( this );
+    addComponent( m_Flags );
+
     connect( this, SIGNAL( progressText( const QString & ) ),
              data, SIGNAL( progressText( const QString & ) ) );
 }
@@ -123,6 +128,7 @@ SkyMapComposite::~SkyMapComposite()
     delete m_skyLabeler;     // These are on the heap to avoid header file hell.
     delete m_skyMesh;
     delete m_Cultures;
+    delete m_Flags;
 }
 
 void SkyMapComposite::update(KStarsData *data, KSNumbers *num )
@@ -243,8 +249,8 @@ void SkyMapComposite::draw( QPainter& psky )
     m_SolarSystem->drawTrails( psky );
     m_SolarSystem->draw( psky );
 
-    //DISABLE_SATELLITES
-    //m_Satellites->draw( psky );
+    // TODO: Fix satellites sometime
+    //    m_Satellites->draw( psky );
 
     m_Horizon->draw( psky );
 
@@ -254,6 +260,8 @@ void SkyMapComposite::draw( QPainter& psky )
     m_CNames->draw( psky );
     m_Stars->drawLabels( psky );
 
+    m_Flags->draw( psky );
+
     m_skyMesh->inDraw( false );
 
     //kDebug() << QString("draw took %1 ms").arg( t.elapsed() );
@@ -578,4 +586,8 @@ QString SkyMapComposite::currentCulture() {
     return m_Cultures->current();
 }
 
+FlagComponent* SkyMapComposite::flags() {
+    return m_Flags;
+}
+
 #include "skymapcomposite.moc"
