@@ -27,8 +27,10 @@
 #include <QResizeEvent>
 #include <QPaintEvent>
 
-#include "skypoint.h"
-#include "skyline.h"
+#include "skyobjects/skypoint.h"
+#include "skyobjects/skyline.h"
+
+#include <config-kstars.h>
 
 #define HOVER_INTERVAL 500 
 
@@ -70,13 +72,13 @@ protected:
     *Constructor.  Read stored settings from KConfig object (focus position,
     *zoom factor, sky color, etc.).  Run initPopupMenus().
     */
-    explicit SkyMap( KStarsData *_data, KStars *_ks = 0 );
+    explicit SkyMap();
 
     SkyMap( SkyMap& skyMap );
 
 public:
 
-    static SkyMap* Create( KStarsData *_data, KStars *_ks = 0 );
+    static SkyMap* Create();
 
     static SkyMap* Instance();
 
@@ -656,6 +658,14 @@ public slots:
     	*in the status bar */
     void slotCancelAngularDistance(void);
 
+#ifdef HAVE_XPLANET
+    /**Run Xplanet to print a view on the screen*/
+    void slotXplanetToScreen();
+
+    /**Run Xplanet to print a view in a file */
+    void slotXplanetToFile();
+#endif
+
 signals:
     /**Emitted by setDestination(), and connected to slewFocus().  Whenever the Destination
     	*point is changed, slewFocus() will iteratively step the Focus toward Destination 
@@ -880,6 +890,14 @@ private:
      */
     void zoomOutOrMagStep( const int modifier );
 
+#ifdef HAVE_XPLANET
+    /**
+     * @short Strart xplanet.
+     * @param outputFile Output file path.
+     */
+    void startXplanet ( const QString & outputFile="" );
+#endif
+
     bool mouseButtonDown, midMouseButtonDown;
     bool mouseMoveCursor;  // true if mouseMoveEvent; needed by setMouseMoveCursor
     bool slewing, clockSlewing;
@@ -910,9 +928,6 @@ private:
     SkyPoint  Focus, OldFocus, ClickedPoint, FocusPoint, MousePoint, Destination, PreviousClickedPoint;
     SkyObject *ClickedObject, *FocusObject, *TransientObject;
 
-    //	QPointArray *pts;	// needed in paintEvent() so it should not every event call reallocated (save time)
-    SkyPoint *sp;			// see line above
-
     SkyLine AngularRuler; //The line for measuring angles in the map
     QRect ZoomRect; //The manual-focus circle.
 
