@@ -41,11 +41,12 @@
 #include "ksutils.h"
 #include "simclock.h"
 #include "infoboxes.h"
-#include "ksfilereader.h"
 #include "kspopupmenu.h"
-#include "ksmoon.h"
+#include "skyobjects/ksmoon.h"
 
+// TODO: Remove if debug key binding is removed
 #include "skycomponents/skylabeler.h"
+#include "skycomponents/starcomponent.h"
 
 void SkyMap::resizeEvent( QResizeEvent * )
 {
@@ -75,7 +76,7 @@ void SkyMap::keyPressEvent( QKeyEvent *e ) {
         //The resumeKey was pressed.  Signal that it was pressed by
         //resetting it to empty; this will break the loop in
         //KStars::waitForKey()
-        data->resumeKey = QString();
+        data->resumeKey = QKeySequence();
         return;
     }
 
@@ -142,96 +143,72 @@ void SkyMap::keyPressEvent( QKeyEvent *e ) {
 
     case Qt::Key_Plus:   //Zoom in
     case Qt::Key_Equal:
-        if ( ks ) ks->slotZoomIn();
+        if ( ks ) 
+            zoomInOrMagStep( e->modifiers() );
         break;
 
     case Qt::Key_Minus:  //Zoom out
     case Qt::Key_Underscore:
-        if ( ks ) ks->slotZoomOut();
-        break;
-
-    //In the following cases, we set slewing=true in order to disengage tracking
-    case Qt::Key_N: //center on north horizon
-        stopTracking();
-        setDestinationAltAz( 15.0, 0.0001 );
-        break;
-
-    case Qt::Key_E: //center on east horizon
-        stopTracking();
-        setDestinationAltAz( 15.0, 90.0 );
-        break;
-
-    case Qt::Key_S: //center on south horizon
-        stopTracking();
-        setDestinationAltAz( 15.0, 180.0 );
-        break;
-
-    case Qt::Key_W: //center on west horizon
-        stopTracking();
-        setDestinationAltAz( 15.0, 270.0 );
-        break;
-
-    case Qt::Key_Z: //center on Zenith
-        stopTracking();
-        setDestinationAltAz( 90.0, focus()->az()->Degrees() );
+        if (  ks ) 
+            zoomOutOrMagStep( e->modifiers() );
         break;
 
     case Qt::Key_0: //center on Sun
-        setClickedObject( data->skyComposite()->findByName("Sun") );
+        setClickedObject( data->skyComposite()->planet( KSPlanetBase::SUN ) );
         setClickedPoint( clickedObject() );
         slotCenter();
         break;
 
     case Qt::Key_1: //center on Mercury
-        setClickedObject( data->skyComposite()->findByName("Mercury") );
+        setClickedObject( data->skyComposite()->planet( KSPlanetBase::MERCURY ) );
         setClickedPoint( clickedObject() );
         slotCenter();
         break;
 
     case Qt::Key_2: //center on Venus
-        setClickedObject( data->skyComposite()->findByName("Venus") );
+        setClickedObject( data->skyComposite()->planet( KSPlanetBase::VENUS ) );
         setClickedPoint( clickedObject() );
         slotCenter();
         break;
 
     case Qt::Key_3: //center on Moon
-        setClickedObject( data->skyComposite()->findByName("Moon") );
+        setClickedObject( data->skyComposite()->planet( KSPlanetBase::MOON ) );
         setClickedPoint( clickedObject() );
         slotCenter();
         break;
 
     case Qt::Key_4: //center on Mars
-        setClickedObject( data->skyComposite()->findByName("Mars") );
+        setClickedObject( data->skyComposite()->planet( KSPlanetBase:: MARS) );
         setClickedPoint( clickedObject() );
         slotCenter();
         break;
 
     case Qt::Key_5: //center on Jupiter
-        setClickedObject( data->skyComposite()->findByName("Jupiter") );
+        setClickedObject( data->skyComposite()->planet( KSPlanetBase::JUPITER ) );
         setClickedPoint( clickedObject() );
         slotCenter();
         break;
 
     case Qt::Key_6: //center on Saturn
-        setClickedObject( data->skyComposite()->findByName("Saturn") );
+        setClickedObject( data->skyComposite()->planet( KSPlanetBase::SATURN ) );
         setClickedPoint( clickedObject() );
         slotCenter();
         break;
 
     case Qt::Key_7: //center on Uranus
-        setClickedObject( data->skyComposite()->findByName("Uranus") );
+        setClickedObject( data->skyComposite()->planet( KSPlanetBase::URANUS ) );
         setClickedPoint( clickedObject() );
         slotCenter();
         break;
 
     case Qt::Key_8: //center on Neptune
-        setClickedObject( data->skyComposite()->findByName("Neptune") );
+        setClickedObject( data->skyComposite()->planet( KSPlanetBase::NEPTUNE ) );
         setClickedPoint( clickedObject() );
         slotCenter();
         break;
 
     case Qt::Key_9: //center on Pluto
-        setClickedObject( data->skyComposite()->findByName("Pluto") );
+        setClickedObject( data->skyComposite()->planet( KSPlanetBase::PLUTO ) );
         setClickedPoint( clickedObject() );
         slotCenter();
         break;
@@ -418,17 +395,34 @@ void SkyMap::keyPressEvent( QKeyEvent *e ) {
         << sl.point(1)->ra()->toHMSString() << endl;
             break;
         **/
-    case Qt::Key_B:  // print labeler info
-        SkyLabeler::Instance()->printInfo();
+        /*
+    case Qt::Key_B:    // print useful debug info about memory allocation for stars
+        data->skyComposite()->getStarComponent()->printDebugInfo();
         break;
-    case Qt::Key_F:  // print labeler info
-        SkyLabeler::Instance()->decDensity();
+    case Qt::Key_F:    // verify the integrity of StarBlockLists
+        data->skyComposite()->getStarComponent()->verifySBLIntegrity();
         break;
-    case Qt::Key_G:  // print labeler info
-        SkyLabeler::Instance()->incDensity();
+    case Qt::Key_G:    // print Cache structure
+        StarComponent::m_StarBlockFactory.printStructure();
         break;
-
-
+    case Qt::Key_H: {  // Frugal memory mode
+        StarComponent::veryFrugalMem = false;
+        if( StarComponent::frugalMem = !(StarComponent::frugalMem) )
+            kDebug() << "Switched to frugal memory mode";
+        else
+            kDebug() << "Switched to generous memory mode";
+        break;
+    }
+    case Qt::Key_I: {  // Very frugal memory mode
+        StarComponent::frugalMem = false;
+        if( StarComponent::veryFrugalMem = !(StarComponent::veryFrugalMem) )
+            kDebug() << "Switched to very frugal memory mode";
+        else
+            kDebug() << "Switched to generous memory mode";
+        
+        break;
+    }
+        */
 
     }
 
@@ -489,7 +483,7 @@ void SkyMap::keyReleaseEvent( QKeyEvent *e ) {
             setDestination( focus() );
 
         showFocusCoords( true );
-        forceUpdate();	// Need a full update to draw faint objects that are not drawn while slewing.
+        forceUpdate();  // Need a full update to draw faint objects that are not drawn while slewing.
         break;
     }
 }
@@ -640,8 +634,11 @@ void SkyMap::mouseMoveEvent( QMouseEvent *e ) {
 }
 
 void SkyMap::wheelEvent( QWheelEvent *e ) {
-    if ( ks && e->delta() > 0 ) ks->slotZoomIn();
-    else if ( ks ) ks->slotZoomOut();
+    if ( ! ks ) return;
+    if ( e->delta() > 0 ) 
+        zoomInOrMagStep ( e->modifiers() );
+    else
+        zoomOutOrMagStep( e->modifiers() );
 }
 
 void SkyMap::mouseReleaseEvent( QMouseEvent * ) {
@@ -868,3 +865,60 @@ void SkyMap::paintEvent( QPaintEvent * )
     //	kDebug() << QString("Skymap draw took %1 ms").arg(t.elapsed());
 }
 
+double SkyMap::zoomFactor( const int modifier ) {
+    double factor = ( modifier & Qt::ControlModifier) ? DZOOM : 2.0; 
+    if ( modifier & Qt::ShiftModifier ) 
+        factor = sqrt( factor );
+
+    return factor;
+}
+
+void SkyMap::zoomInOrMagStep( const int modifier ) {
+    if ( modifier & Qt::AltModifier )
+        incMagLimit( modifier );
+    else
+        ks->zoomIn( zoomFactor( modifier ) );
+}
+
+    
+void SkyMap::zoomOutOrMagStep( const int modifier ) {
+    if ( modifier & Qt::AltModifier )
+        decMagLimit( modifier );
+    else
+        ks->zoomOut( zoomFactor (modifier ) );
+}
+
+void SkyMap::zoomIn( const int modifier) {
+    ks->zoomIn( zoomFactor( modifier) );
+}
+
+void SkyMap::zoomOut( const int modifier) {
+    ks->zoomOut( zoomFactor( modifier ) );
+}
+
+double SkyMap::magFactor( const int modifier ) {
+    double factor = ( modifier & Qt::ControlModifier) ? 0.2 : 1.0; 
+    if ( modifier & Qt::ShiftModifier ) 
+        factor /= 2.0;
+
+    return factor;
+}
+
+void SkyMap::incMagLimit( const int modifier ) {
+    double limit = 2.222 * log10( (float)Options::starDensity() ) + 0.35;
+    limit += magFactor( modifier );
+    if ( limit > 7.94 ) limit = 7.94;
+    Options::setStarDensity( pow( 10, ( limit - 0.35 ) / 2.222) );
+    //printf("maglim set to %3.1f\n", limit);
+    forceUpdate();
+}
+
+void SkyMap::decMagLimit( const int modifier ) {
+    double limit = 2.222 * log10( (float)Options::starDensity() ) + 0.35;
+    limit -= magFactor( modifier );
+    if ( limit < 3.55 ) limit = 3.55;
+    Options::setStarDensity( pow( 10, ( limit - 0.35 ) / 2.222) );
+    //printf("maglim set to %3.1f\n", limit);
+    forceUpdate();
+}
+
