@@ -20,19 +20,24 @@
 #include <math.h>
 
 #include "ksnumbers.h"
-#include "ksplanetbase.h"
-#include "ksplanet.h"
-#include "ksasteroid.h"
-#include "kscomet.h"
+#include "skyobjects/ksplanetbase.h"
+#include "skyobjects/ksplanet.h"
+#include "skyobjects/ksasteroid.h"
+#include "skyobjects/kscomet.h"
 #include "kstarsdata.h"
 
 KSConjunct::KSConjunct() {
-
-  ksdata = NULL;
-
+    geoPlace = KStarsData::Instance()->geo();
 }
 
-QMap<long double, dms> KSConjunct::findClosestApproach(SkyObject& Object1, KSPlanetBase& Object2, long double startJD, long double stopJD, dms maxSeparation) {
+void KSConjunct::setGeoLocation( GeoLocation *geo ) {
+    if( geo != NULL )
+        geoPlace = geo;
+    else
+        geoPlace = KStarsData::Instance()->geo();
+}
+
+QMap<long double, dms> KSConjunct::findClosestApproach(SkyObject& Object1, KSPlanetBase& Object2, long double startJD, long double stopJD, dms maxSeparation,bool _opposition) {
 
   QMap<long double, dms> Separations;
   QPair<long double, dms> extremum;
@@ -40,8 +45,7 @@ QMap<long double, dms> KSConjunct::findClosestApproach(SkyObject& Object1, KSPla
   dms prevDist;
   double step, step0;
   int Sign, prevSign;
-
-  ksdata = KStarsData::Instance();
+  opposition=_opposition;
   //  kDebug() << "Entered KSConjunct::findClosestApproach() with startJD = " << (double)startJD;
   //  kDebug() << "Initial Positional Information: \n";
   //  kDebug() << Object1.name() << ": RA = " << Object1.ra() -> toHMSString() << "; Dec = " << Object1.dec() -> toDMSString() << "\n";
@@ -61,7 +65,7 @@ QMap<long double, dms> KSConjunct::findClosestApproach(SkyObject& Object1, KSPla
 
   step = step0;
   
-//  kDebug() << "Initial Separation between " << Object1.name() << " and " << Object2.name() << " = " << (prevDist.toDMSString());
+  //	kDebug() << "Initial Separation between " << Object1.name() << " and " << Object2.name() << " = " << (prevDist.toDMSString());
 
   long double jd = startJD;
   prevDist = findDistance(jd, &Object1, &Object2);
@@ -72,10 +76,10 @@ QMap<long double, dms> KSConjunct::findClosestApproach(SkyObject& Object1, KSPla
     
     Dist = findDistance(jd, &Object1, &Object2);
     Sign = sgn(Dist.Degrees() - prevDist.Degrees()); 
-//    kDebug() << "Dist = " << Dist.toDMSString() << "; prevDist = " << prevDist.toDMSString() << "; Difference = " << (Dist.Degrees() - prevDist.Degrees()) << "; Step = " << step;
+    //	kDebug() << "Dist = " << Dist.toDMSString() << "; prevDist = " << prevDist.toDMSString() << "; Difference = " << (Dist.Degrees() - prevDist.Degrees()) << "; Step = " << step;
 
     //How close are we to a conjunction, and how fast are we approaching one?
-    double factor = fabs( Dist.Degrees() / (Dist.Degrees() - prevDist.Degrees()) );
+    double factor = fabs( (Dist.Degrees() - prevDist.Degrees()) / Dist.Degrees());
     if ( factor > 10.0 ) { //let's go faster!
         step = step0 * factor/10.0;
     } else { //slow down, we're getting close!
@@ -91,7 +95,7 @@ QMap<long double, dms> KSConjunct::findClosestApproach(SkyObject& Object1, KSPla
             while ( jd <= stopJD ) {
                 Dist = findDistance(jd, &Object1, &Object2);
                 Sign = sgn(Dist.Degrees() - prevDist.Degrees()); 
-                //                kDebug() << "Dist=" << Dist.toDMSString() << "; prevDist=" << prevDist.toDMSString() << "; Diff=" << (Dist.Degrees() - prevDist.Degrees()) << "djd=" << (int)(jd - startJD);
+                //	kDebug() << "Dist=" << Dist.toDMSString() << "; prevDist=" << prevDist.toDMSString() << "; Diff=" << (Dist.Degrees() - prevDist.Degrees()) << "djd=" << (int)(jd - startJD);
                 if ( Sign != prevSign ) break;
                 
                 prevDist = Dist;
@@ -100,7 +104,7 @@ QMap<long double, dms> KSConjunct::findClosestApproach(SkyObject& Object1, KSPla
             }
         }
         
-        //        kDebug() << "Sign = " << Sign << " and " << "prevSign = " << prevSign << ": Entering findPrecise()\n";
+        //	kDebug() << "Sign = " << Sign << " and " << "prevSign = " << prevSign << ": Entering findPrecise()\n";
         if(findPrecise(&extremum, &Object1, &Object2, jd, step, Sign))
             if(extremum.second.radians() < maxSeparation.radians())
                 Separations.insert(extremum.first, extremum.second);
@@ -115,45 +119,29 @@ QMap<long double, dms> KSConjunct::findClosestApproach(SkyObject& Object1, KSPla
 }
 
 
-dms KSConjunct::findDistance(long double jd, SkyObject *Object1, KSPlanetBase *Object2) {
-
+dms KSConjunct::findDistance(long double jd, SkyObject *Object1, KSPlanetBase *Object2)
+{
   KStarsDateTime t(jd);
   KSNumbers num(jd);
   dms dist;
 
-  if(ksdata == NULL)
-    ksdata = KStarsData::Instance();
-
-  KSPlanet *m_Earth = new KSPlanet( ksdata, I18N_NOOP( "Earth" ), QString(), QColor( "white" ), 12756.28 /*diameter in km*/ );
+  KSPlanet *m_Earth = new KSPlanet( I18N_NOOP( "Earth" ), QString(), QColor( "white" ), 12756.28 /*diameter in km*/ );
   m_Earth -> findPosition( &num );
-  dms LST(ksdata->geo()->GSTtoLST(t.gst()));
+  dms LST(geoPlace->GSTtoLST(t.gst()));
 
+  // FIXME: This should be virtual functions or whatever
   if( Object1->isSolarSystem() ) {
-      switch( Object1->type() ) {
-      case 2: {
-          KSPlanet *Planet = (KSPlanet *)Object1;
-          Planet->findPosition(&num, ksdata->geo()->lat(), &LST, (KSPlanetBase *)m_Earth);
-          break;
-      }
-      case 9: {
-          KSComet *Comet = (KSComet *)Object1;
-          Comet->findPosition(&num, ksdata->geo()->lat(), &LST, (KSPlanetBase *)m_Earth);
-          break;
-      }
-      case 10: {
-          KSAsteroid *Asteroid = (KSAsteroid *)Object1;
-          Asteroid->findPosition(&num, ksdata->geo()->lat(), &LST, (KSPlanetBase *)m_Earth);
-          break;
-      }
-      }
-  }
-  else
+      KSPlanetBase* p = reinterpret_cast<KSPlanetBase*>(Object1);
+      p->findPosition(&num, geoPlace->lat(), &LST, m_Earth);
+  } else {
       Object1->updateCoords( &num );
+  }
 
-  Object2->findPosition(&num, ksdata->geo()->lat(), &LST, (KSPlanetBase *)m_Earth);
-
+  Object2->findPosition(&num, geoPlace->lat(), &LST, m_Earth);
   dist.setRadians(Object1 -> angularDistanceTo(Object2).radians());
-  
+  if( opposition ) {
+      dist.set( 180 - dist.Degrees() );
+  }
   return dist;
 }
 
