@@ -41,22 +41,22 @@
 #include "obslistwizard.h"
 #include "kstars.h"
 #include "kstarsdata.h"
-#include "skyobject.h"
-#include "starobject.h"
+#include "skyobjects/skyobject.h"
+#include "skyobjects/starobject.h"
 #include "skymap.h"
-#include "detaildialog.h"
+#include "dialogs/detaildialog.h"
 #include "tools/altvstime.h"
 #include "Options.h"
 
 #include <config-kstars.h>
 
 #ifdef HAVE_INDI_H
-#include "indimenu.h"
-#include "indielement.h"
-#include "indiproperty.h"
-#include "indidevice.h"
-#include "devicemanager.h"
-#include "indistd.h"
+#include "indi/indimenu.h"
+#include "indi/indielement.h"
+#include "indi/indiproperty.h"
+#include "indi/indidevice.h"
+#include "indi/devicemanager.h"
+#include "indi/indistd.h"
 #endif
 
 //
@@ -171,7 +171,7 @@ void ObservingList::slotAddObject( SkyObject *obj ) {
     m_CurrentObject = obj;
     QList<QStandardItem*> itemList;
     QString smag = "--";
-    if ( obj->mag() < 90.0 ) smag = QString::number( obj->mag(), 'g', 2 );
+    if (  - 30.0 < obj->mag() && obj->mag() < 90.0 ) smag = QString::number( obj->mag(), 'g', 2 ); // The lower limit to avoid display of unrealistic comet magnitudes
     itemList << new QStandardItem( obj->translatedName() ) 
             << new QStandardItem( obj->ra()->toHMSString() ) 
             << new QStandardItem( obj->dec()->toDMSString() ) 
@@ -332,8 +332,7 @@ void ObservingList::slotNewSelection() {
         ui->DetailsButton->setEnabled( false );
         ui->AVTButton->setEnabled( false );
         ui->RemoveButton->setEnabled( false );
-        //FIXME: after 4.0, set this label to "Select one object to record notes on it here"
-        ui->NotesLabel->setText( i18n( "observing notes for object:" ) );
+        ui->NotesLabel->setText( i18n( "Select an object to record notes on it here:" ) );
         ui->NotesLabel->setEnabled( false );
         ui->NotesEdit->setEnabled( false );
         m_CurrentObject = 0;
@@ -348,8 +347,7 @@ void ObservingList::slotNewSelection() {
         ui->DetailsButton->setEnabled( false );
         ui->AVTButton->setEnabled( true );
         ui->RemoveButton->setEnabled( true );
-        //FIXME: after 4.0, set this label to "Select one object to record notes on it here"
-        ui->NotesLabel->setText( i18n( "observing notes for object:" ) );
+        ui->NotesLabel->setText( i18n( "Select an object to record notes on it here:" ) );
         ui->NotesLabel->setEnabled( false );
         ui->NotesEdit->setEnabled( false );
         m_CurrentObject = 0;
@@ -504,8 +502,9 @@ void ObservingList::slotSlewToObject()
 //Should have one window whose target object changes with selection
 void ObservingList::slotDetails() {
     if ( currentObject() ) {
-        DetailDialog dd( currentObject(), ks->data()->lt(), ks->geo(), ks );
-        dd.exec();
+        QPointer<DetailDialog> dd = new DetailDialog( currentObject(), ks->data()->lt(), ks->geo(), ks );
+        dd->exec();
+	delete dd;
     }
 }
 
@@ -513,15 +512,16 @@ void ObservingList::slotAVT() {
     QModelIndexList selectedItems = m_SortModel->mapSelectionToSource( ui->TableView->selectionModel()->selection() ).indexes();
 
     if ( selectedItems.size() ) {
-        AltVsTime avt( ks );
+        QPointer<AltVsTime> avt = new AltVsTime( ks );
         foreach ( const QModelIndex &i, selectedItems ) {
             foreach ( SkyObject *o, obsList() ) {
                 if ( o->translatedName() == i.data().toString() )
-                    avt.processObject( o );
+                    avt->processObject( o );
             }
         }
 
-        avt.exec();
+        avt->exec();
+	delete avt;
     }
 }
 
@@ -563,7 +563,7 @@ void ObservingList::slotOpenList() {
                 f.setFileName( FileName );
 
         } else {
-            FileName = fileURL.path();
+            FileName = fileURL.toLocalFile();
             f.setFileName( FileName );
         }
 
@@ -585,7 +585,7 @@ void ObservingList::slotOpenList() {
 
             //If the object is named "star", add it by coordinates
             SkyObject *o;
-            if ( line.startsWith( "star" ) ) {
+            if ( line.startsWith( QLatin1String( "star" ) ) ) {
                 QStringList fields = line.split( ' ', QString::SkipEmptyParts );
                 dms ra = dms::fromString( fields[1], false ); //false = hours
                 dms dc = dms::fromString( fields[2], true );  //true  = degrees
@@ -691,15 +691,16 @@ void ObservingList::slotSaveList() {
 }
 
 void ObservingList::slotWizard() {
-    ObsListWizard wizard( ks );
-    if ( wizard.exec() == QDialog::Accepted ) {
+    QPointer<ObsListWizard> wizard = new ObsListWizard( ks );
+    if ( wizard->exec() == QDialog::Accepted ) {
         //Make sure current list is saved
         saveCurrentList();
 
-        foreach ( SkyObject *o, wizard.obsList() ) {
+        foreach ( SkyObject *o, wizard->obsList() ) {
             slotAddObject( o );
         }
     }
+    delete wizard;
 }
 
 void ObservingList::slotToggleSize() {
