@@ -25,10 +25,10 @@
 #include "kstars.h"
 #include "kstarsdata.h"
 #include "geolocation.h"
-#include "locationdialog.h"
-#include "skyobject.h"
-#include "deepskyobject.h"
-#include "starobject.h"
+#include "dialogs/locationdialog.h"
+#include "skyobjects/skyobject.h"
+#include "skyobjects/deepskyobject.h"
+#include "skyobjects/starobject.h"
 #include "widgets/dmsbox.h"
 #include "widgets/magnitudespinbox.h"
 #include "skycomponents/constellationboundary.h"
@@ -57,19 +57,23 @@ ObsListWizard::ObsListWizard( KStars *ksparent )
     connect( this, SIGNAL( user1Clicked() ), this, SLOT( slotPrevPage() ) );
     connect( this, SIGNAL( user2Clicked() ), this, SLOT( slotNextPage() ) );
 
-    //Update the count of objects when certain UI elements are modified
-    connect( olw->TypeList, SIGNAL( itemSelectionChanged() ), this, SLOT( slotUpdateObjectCount() ) );
-    connect( olw->ConstellationList, SIGNAL( itemSelectionChanged() ), this, SLOT( slotUpdateObjectCount() ) );
+    //Update the count of objects when the user asks for it
+    connect( olw->updateButton, SIGNAL( clicked() ), this, SLOT( slotUpdateObjectCount() ) );
+    
+    // Enable the update count button when certain elements are changed
+    connect( olw->TypeList, SIGNAL( itemSelectionChanged() ), this, SLOT( slotObjectCountDirty() ) );
+    connect( olw->ConstellationList, SIGNAL( itemSelectionChanged() ), this, SLOT( slotObjectCountDirty() ) );
     connect( olw->RAMin, SIGNAL( lostFocus() ), this, SLOT( slotParseRegion() ) );
     connect( olw->RAMax, SIGNAL( lostFocus() ), this, SLOT( slotParseRegion() ) );
     connect( olw->DecMin, SIGNAL( lostFocus() ), this, SLOT( slotParseRegion() ) );
     connect( olw->DecMax, SIGNAL( lostFocus() ), this, SLOT( slotParseRegion() ) );
     connect( olw->RA, SIGNAL( lostFocus() ), this, SLOT( slotParseRegion() ) );
     connect( olw->Dec, SIGNAL( lostFocus() ), this, SLOT( slotParseRegion() ) );
-    connect( olw->Radius, SIGNAL( lostFocus() ), this, SLOT( slotUpdateObjectCount() ) );
-    connect( olw->Date, SIGNAL( dateChanged(const QDate&) ), this, SLOT( slotUpdateObjectCount() ) );
-    connect( olw->Mag, SIGNAL( valueChanged( double ) ), this, SLOT( slotUpdateObjectCount() ) );
-    connect( olw->IncludeNoMag, SIGNAL( clicked() ), this, SLOT( slotUpdateObjectCount() ) );
+    connect( olw->Radius, SIGNAL( lostFocus() ), this, SLOT( slotObjectCountDirty() ) );
+    connect( olw->Date, SIGNAL( dateChanged(const QDate&) ), this, SLOT( slotObjectCountDirty() ) );
+    connect( olw->Mag, SIGNAL( valueChanged( double ) ), this, SLOT( slotObjectCountDirty() ) );
+    connect( olw->IncludeNoMag, SIGNAL( clicked() ), this, SLOT( slotObjectCountDirty() ) );
+
     connect( olw->SelectByDate, SIGNAL( clicked() ), this, SLOT( slotToggleDateWidgets() ) );
     connect( olw->SelectByMagnitude, SIGNAL( clicked() ), this, SLOT( slotToggleMagWidgets() ) );
 
@@ -226,15 +230,16 @@ void ObsListWizard::slotSolarSystemButton()
 
 void ObsListWizard::slotChangeLocation()
 {
-    LocationDialog ld( ksw );
+    QPointer<LocationDialog> ld = new LocationDialog( ksw );
 
-    if ( ld.exec() == QDialog::Accepted ) {
+    if ( ld->exec() == QDialog::Accepted ) {
         //set geographic location
-        if ( ld.selectedCity() ) {
-            geo = ld.selectedCity();
+        if ( ld->selectedCity() ) {
+            geo = ld->selectedCity();
             olw->LocationButton->setText( geo->fullName() );
         }
     }
+    delete ld;
 }
 
 void ObsListWizard::slotToggleDateWidgets()
@@ -242,15 +247,16 @@ void ObsListWizard::slotToggleDateWidgets()
     olw->Date->setEnabled( olw->SelectByDate->isChecked() );
     olw->LocationButton->setEnabled( olw->SelectByDate->isChecked() );
 
-    slotUpdateObjectCount();
+    //    slotUpdateObjectCount();
+    slotObjectCountDirty();
 }
 
 void ObsListWizard::slotToggleMagWidgets()
 {
     olw->Mag->setEnabled( olw->SelectByMagnitude->isChecked() );
     olw->IncludeNoMag->setEnabled( olw->SelectByMagnitude->isChecked() );
-
-    slotUpdateObjectCount();
+    slotObjectCountDirty();
+    //    slotUpdateObjectCount();
 }
 
 void ObsListWizard::slotParseRegion()
@@ -294,7 +300,8 @@ void ObsListWizard::slotParseRegion()
                 }
             }
 
-            slotUpdateObjectCount();
+            //            slotUpdateObjectCount();
+            slotObjectCountDirty();
         }
 
     } else {
@@ -315,11 +322,16 @@ void ObsListWizard::slotParseRegion()
                 return;
             }
 
-            slotUpdateObjectCount();
+            //            slotUpdateObjectCount();
+            slotObjectCountDirty();
         }
     }
 }
 
+void ObsListWizard::slotObjectCountDirty() {
+    olw->updateButton->setDisabled( false );
+}
+
 void ObsListWizard::slotUpdateObjectCount()
 {
     QApplication::setOverrideCursor( Qt::WaitCursor );
@@ -345,6 +357,7 @@ void ObsListWizard::slotUpdateObjectCount()
 
     applyFilters( false ); //false = only adjust counts, do not build list
     QApplication::restoreOverrideCursor();
+    olw->updateButton->setDisabled( true );
 }
 
 void ObsListWizard::applyFilters( bool doBuildList )
@@ -413,28 +426,28 @@ void ObsListWizard::applyFilters( bool doBuildList )
         if ( needRegion ) {
             applyRegionFilter( (SkyObject*)ksw->data()->skyComposite()->findByName("Sun"), doBuildList );
             applyRegionFilter( (SkyObject*)ksw->data()->skyComposite()->findByName("Moon"), doBuildList );
-            applyRegionFilter( (SkyObject*)ksw->data()->skyComposite()->findByName("Mercury"), doBuildList );
-            applyRegionFilter( (SkyObject*)ksw->data()->skyComposite()->findByName("Venus"), doBuildList );
-            applyRegionFilter( (SkyObject*)ksw->data()->skyComposite()->findByName("Mars"), doBuildList );
-            applyRegionFilter( (SkyObject*)ksw->data()->skyComposite()->findByName("Jupiter"), doBuildList );
-            applyRegionFilter( (SkyObject*)ksw->data()->skyComposite()->findByName("Saturn"), doBuildList );
-            applyRegionFilter( (SkyObject*)ksw->data()->skyComposite()->findByName("Uranus"), doBuildList );
-            applyRegionFilter( (SkyObject*)ksw->data()->skyComposite()->findByName("Neptune"), doBuildList );
-            applyRegionFilter( (SkyObject*)ksw->data()->skyComposite()->findByName("Pluto"), doBuildList );
+            applyRegionFilter( (SkyObject*)ksw->data()->skyComposite()->findByName(i18n( "Mercury" )), doBuildList );
+            applyRegionFilter( (SkyObject*)ksw->data()->skyComposite()->findByName(i18n( "Venus" )), doBuildList );
+            applyRegionFilter( (SkyObject*)ksw->data()->skyComposite()->findByName(i18n( "Mars" )), doBuildList );
+            applyRegionFilter( (SkyObject*)ksw->data()->skyComposite()->findByName(i18n( "Jupiter" )), doBuildList );
+            applyRegionFilter( (SkyObject*)ksw->data()->skyComposite()->findByName(i18n( "Saturn" )), doBuildList );
+            applyRegionFilter( (SkyObject*)ksw->data()->skyComposite()->findByName(i18n( "Uranus" )), doBuildList );
+            applyRegionFilter( (SkyObject*)ksw->data()->skyComposite()->findByName(i18n( "Neptune" )), doBuildList );
+            applyRegionFilter( (SkyObject*)ksw->data()->skyComposite()->findByName(i18n( "Pluto" )), doBuildList );
         }
 
         //Filter objects visible from geo at Date
         if ( olw->SelectByDate->isChecked() ) {
             applyObservableFilter( (SkyObject*)ksw->data()->skyComposite()->findByName("Sun"), doBuildList );
             applyObservableFilter( (SkyObject*)ksw->data()->skyComposite()->findByName("Moon"), doBuildList );
-            applyObservableFilter( (SkyObject*)ksw->data()->skyComposite()->findByName("Mercury"), doBuildList );
-            applyObservableFilter( (SkyObject*)ksw->data()->skyComposite()->findByName("Venus"), doBuildList );
-            applyObservableFilter( (SkyObject*)ksw->data()->skyComposite()->findByName("Mars"), doBuildList );
-            applyObservableFilter( (SkyObject*)ksw->data()->skyComposite()->findByName("Jupiter"), doBuildList );
-            applyObservableFilter( (SkyObject*)ksw->data()->skyComposite()->findByName("Saturn"), doBuildList );
-            applyObservableFilter( (SkyObject*)ksw->data()->skyComposite()->findByName("Uranus"), doBuildList );
-            applyObservableFilter( (SkyObject*)ksw->data()->skyComposite()->findByName("Neptune"), doBuildList );
-            applyObservableFilter( (SkyObject*)ksw->data()->skyComposite()->findByName("Pluto"), doBuildList );
+            applyObservableFilter( (SkyObject*)ksw->data()->skyComposite()->findByName(i18n( "Mercury" )), doBuildList );
+            applyObservableFilter( (SkyObject*)ksw->data()->skyComposite()->findByName(i18n( "Venus" )), doBuildList );
+            applyObservableFilter( (SkyObject*)ksw->data()->skyComposite()->findByName(i18n( "Mars" )), doBuildList );
+            applyObservableFilter( (SkyObject*)ksw->data()->skyComposite()->findByName(i18n( "Jupiter" )), doBuildList );
+            applyObservableFilter( (SkyObject*)ksw->data()->skyComposite()->findByName(i18n( "Saturn" )), doBuildList );
+            applyObservableFilter( (SkyObject*)ksw->data()->skyComposite()->findByName(i18n( "Uranus" )), doBuildList );
+            applyObservableFilter( (SkyObject*)ksw->data()->skyComposite()->findByName(i18n( "Neptune" )), doBuildList );
+            applyObservableFilter( (SkyObject*)ksw->data()->skyComposite()->findByName(i18n( "Pluto" )), doBuildList );
         }
     }
 
