@@ -13,17 +13,27 @@
 #define LAYERMANAGER_H
 
 // Qt
+#include <QtCore/QList>
 #include <QtCore/QObject>
+#include <QtCore/QString>
 
 // Local dir
-#include "PluginManager.h"
+#include "marble_export.h"
 
+class QPoint;
+
+namespace Marble
+{
+
+class AbstractDataPlugin;
+class AbstractDataPluginItem;
 class LayerManagerPrivate;
-class GeoSceneDocument;
 class GeoPainter;
+class GeoSceneDocument;
 class ViewParams;
-class MarbleAbstractLayer;
-class MarbleAbstractFloatItem;
+class RenderPlugin;
+class AbstractFloatItem;
+class AbstractDataPlugin;
 class MarbleDataFacade;
 
 /**
@@ -39,10 +49,31 @@ class MARBLE_EXPORT LayerManager : public QObject
     explicit LayerManager( MarbleDataFacade*, QObject *parent = 0);
     ~LayerManager();
 
-    void renderLayers( GeoPainter *painter, ViewParams *viewParams );
+    void renderLayers( GeoPainter *painter, ViewParams *viewParams, const QStringList& renderPositions );
 
-    QList<MarbleAbstractLayer *> layerPlugins() const;
-    QList<MarbleAbstractFloatItem *> floatItems() const;
+    void renderLayer( GeoPainter *painter, ViewParams *viewParams, const QString& renderPosition  );
+
+    
+    /**
+     * @brief Returns a list of all RenderPlugins on the layer, this includes float items
+     * @return the list of RenderPlugins
+     */
+    QList<RenderPlugin *>      renderPlugins() const;
+    /**
+     * @brief Returns a list of all FloatItems on the layer
+     * @return the list of the floatItems
+     */
+    QList<AbstractFloatItem *> floatItems()    const;
+    /**
+     * @brief Returns a list of all DataPlugins on the layer
+     * @return the list of DataPlugins
+     */
+    QList<AbstractDataPlugin *> dataPlugins()  const;
+    
+    /**
+     * @brief Returns all items of dataPlugins on the position curpos 
+     */
+    QList<AbstractDataPluginItem *> whichItemAt( const QPoint& curpos ) const;
 
  Q_SIGNALS:
     /**
@@ -53,7 +84,7 @@ class MARBLE_EXPORT LayerManager : public QObject
  public Q_SLOTS:
     void loadLayers();
 
-    void syncViewParamsAndPlugins( GeoSceneDocument *mapTheme );
+    void syncViewParamsAndPlugins( Marble::GeoSceneDocument *mapTheme );
     void syncActionWithProperty( QString, bool );
     void syncPropertyWithAction( QString, bool );
  
@@ -63,5 +94,6 @@ class MARBLE_EXPORT LayerManager : public QObject
     LayerManagerPrivate  * const d;
 };
 
+}
 
 #endif // LAYERMANAGER_H
