@@ -23,15 +23,14 @@
 
 
 #include <QtCore/QSize>
+#include <QtCore/QString>
 #include <QtCore/QObject>
-#include <QtCore/QTimer>
-#include <QtGui/QImage>
+#include <QtGui/QFont>
 #include <QtGui/QPixmap>
 
-//#include <QtDBus/QtDBus>
-
 #include "marble_export.h"
-#include "GeoDataPoint.h"       // In geodata/data/
+#include "GeoDataCoordinates.h"       // In geodata/data/
+#include "Quaternion.h"
 #include "global.h"             // types needed in all of marble.
 
 // Qt
@@ -39,6 +38,10 @@ class QAbstractItemModel;
 class QModelIndex;
 class QItemSelectionModel;
 class QStyleOptionGraphicsItem;
+class QUrl;
+
+namespace Marble
+{
 
 // MarbleMap 
 //class MarbleWidgetInputHandler;
@@ -46,18 +49,15 @@ class QStyleOptionGraphicsItem;
 class MarbleMapPrivate;
 
 // Marble
-class BoundingBox;
 class MarbleModel;
 class ViewParams;
-class HttpDownloadManager;
 class MeasureTool;
 class SunLocator;
 class GpxFileModel;
 class FileViewModel;
 class GeoPainter;
-class MarbleAbstractLayer;
-class MarbleAbstractFloatItem;
-
+class RenderPlugin;
+class AbstractFloatItem;
 
 /**
  * @short A class that can paint a view of the earth.
@@ -93,7 +93,7 @@ class MarbleAbstractFloatItem;
 class MARBLE_EXPORT MarbleMap : public QObject
 {
     Q_OBJECT
-    Q_CLASSINFO("D-Bus Interface", "org.kde.marble")
+    Q_CLASSINFO("D-Bus Interface", "org.kde.MarbleMap")
 
  public:
 
@@ -106,7 +106,7 @@ class MARBLE_EXPORT MarbleMap : public QObject
      * MarbleMap.  The widget will create its own MarbleModel when
      * created.
      */
-    explicit MarbleMap();
+    MarbleMap();
 
     /**
      * @brief Construct a new MarbleMap.
@@ -135,16 +135,6 @@ class MARBLE_EXPORT MarbleMap : public QObject
     int   width()  const;
     int   height() const;
 
-    /**
-     * @brief Set the download manager to load missing tiles
-     * @param manager the manager instance
-     *
-     * The instance will be destructed by MarbleMap when not
-     * used any longer.
-     */
-    void setDownloadManager( HttpDownloadManager *downloadManager );
-
-
     /**
      * @brief  Return the radius of the globe in pixels.
      */
@@ -154,7 +144,7 @@ class MARBLE_EXPORT MarbleMap : public QObject
      * @brief  Set the radius of the globe in pixels.
      * @param  radius  The new globe radius value in pixels.
      */
-    void        setRadius(const int radius);
+    void        setRadius(int radius);
 
     /**
      * @brief Return the current zoom level.
@@ -164,13 +154,13 @@ class MARBLE_EXPORT MarbleMap : public QObject
     /**
      * @brief Return the current distance.
      */
-    double      distance() const;
+    qreal      distance() const;
 
     /**
      * @brief  Set the distance of the observer to the globe in km.
      * @param  distance  The new distance in km.
      */
-    void        setDistance( double distance );
+    void        setDistance( qreal distance );
 
     /**
      * @brief Return the current distance string.
@@ -206,8 +196,8 @@ class MARBLE_EXPORT MarbleMap : public QObject
      * @return @c true  if the geographical coordinates are visible on the screen
      *         @c false if the geographical coordinates are not visible on the screen
      */
-    bool screenCoordinates( const double lon, const double lat,
-                            int& x, int& y );
+    bool screenCoordinates( qreal lon, qreal lat,
+                            qreal& x, qreal& y );
 
     /**
      * @brief Get the Y coordinate of the North Pole.
@@ -224,59 +214,54 @@ class MARBLE_EXPORT MarbleMap : public QObject
      * @return @c true  if the pixel (x, y) is within the globe
      *         @c false if the pixel (x, y) is outside the globe, i.e. in space.
      */
-    bool geoCoordinates( const int x, const int y,
-                         double& lon, double& lat,
-                         GeoDataPoint::Unit = GeoDataPoint::Degree );
-
-    /**
-     * @brief Get a quaternion representing a point on the earth corresponding to a pixel in the map.
-     * @param x  the x coordinate of the pixel
-     * @param y  the y coordinate of the pixel
-     * @param q  the out parameter where the result is returned
-     * @return @c true  if the pixel (x, y) is within the globe
-     *         @c false if the pixel (x, y) is outside the globe, i.e. in space
-     */
-    bool    globalQuaternion( int x, int y, Quaternion &q);
-    // FIXME: Make the names of globalQuaternion() and
-    //        geoCoordinates() follow a pattern.
+    bool geoCoordinates( int x, int y,
+                         qreal& lon, qreal& lat,
+                         GeoDataCoordinates::Unit = GeoDataCoordinates::Degree );
 
     /**
      * @brief Return the longitude of the center point.
      */
-    double  centerLongitude() const;
+    qreal  centerLongitude() const;
 
     /**
      * @brief Return the latitude of the center point.
      */
-    double  centerLatitude()  const;
+    qreal  centerLatitude()  const;
 
     /**
      * @brief returns the model for all the placemarks on the globe.
      */
-    QAbstractItemModel *placeMarkModel() const;
+    QAbstractItemModel *placemarkModel() const;
 
     /**
      * @brief returns the selection model for all the placemarks on the globe.
      */
-    QItemSelectionModel *placeMarkSelectionModel() const;
+    QItemSelectionModel *placemarkSelectionModel() const;
 
     /**
      * @brief  Return how much the map will move if one of the move slots are called.
      * @return The move step.
      */
-    double  moveStep();
+    qreal  moveStep();
 
     /**
      * @brief  Add a GeoDataPlacemark file to the model.
-     * @param  filename  the filename of the file containing the PlaceMarks.
+     * @param  filename  the filename of the file containing the Placemarks.
      */
-    void addPlaceMarkFile( const QString &filename );
+    void addPlacemarkFile( const QString &filename );
 
     /**
-     * @brief  Add a GeoDataPlacemark data as string to the model.
-     * @param  data  the string containing the PlaceMarks.
+     * @brief  Add GeoDataPlacemark data as string to the model.
+     * @param  data  the string containing the Placemarks.
+     * @param key  the string needed to identify the data
      */
-    void addPlaceMarkData( const QString &data );
+    void addPlacemarkData( const QString& data, const QString& key = "data" );
+    
+    /**
+     * @brief  remove data or files from the model.
+     * @param key  either the filename or the string used to identify the data in addPlacemarkFile and addPlacemarkData
+     */
+    void removePlacemarkKey( const QString& key );
 
     /**
      * @brief  Return the quaternion that specifies the rotation of the globe.
@@ -325,6 +310,12 @@ class MARBLE_EXPORT MarbleMap : public QObject
      */
     bool  showAtmosphere() const;
 
+    /**
+     * @brief  Return whether the crosshairs are visible.
+     * @return The crosshairs' visibility.
+     */
+    bool  showCrosshairs() const;
+
     /**
      * @brief  Return whether the coordinate grid is visible.
      * @return The coordinate grid visibility.
@@ -421,8 +412,8 @@ class MARBLE_EXPORT MarbleMap : public QObject
      */
     SunLocator* sunLocator();
 
-    QList<MarbleAbstractLayer *> layerPlugins() const;
-    QList<MarbleAbstractFloatItem *> floatItems() const;
+    QList<RenderPlugin *> renderPlugins() const;
+    QList<AbstractFloatItem *> floatItems() const;
 
  public Q_SLOTS:
 
@@ -472,7 +463,7 @@ class MARBLE_EXPORT MarbleMap : public QObject
      * of (lon, lat), otherwise the resulting angle will be the sum of
      * the previous position and the two offsets.
      */
-    void  rotateBy( const double &deltaLon, const double &deltaLat );
+    void  rotateBy( const qreal &deltaLon, const qreal &deltaLat );
 
     /**
      * @brief  Rotate the view by the angle specified by a Quaternion.
@@ -487,7 +478,7 @@ class MARBLE_EXPORT MarbleMap : public QObject
      * @param  lon  an angle parallel to the longitude lines
      *              +180(W) - -180(E)
      */
-    void  centerOn( const double &lon, const double &lat );
+    void  centerOn( const qreal &lon, const qreal &lat );
 
     /**
      * @brief  Center the view on a point
@@ -499,13 +490,13 @@ class MARBLE_EXPORT MarbleMap : public QObject
      * @brief  Set the latitude for the center point
      * @param  lat  the new value for the latitude
      */
-    void setCenterLatitude( double lat );
+    void setCenterLatitude( qreal lat );
 
     /**
      * @brief  Set the longitude for the center point
      * @param  lon  the new value for the longitude
      */
-    void setCenterLongitude( double lon );
+    void setCenterLongitude( qreal lon );
 
     /**
      * @brief  Get the Projection used for the map
@@ -527,20 +518,20 @@ class MARBLE_EXPORT MarbleMap : public QObject
      * @param  lat  the latitude of the home point.
      * @param  zoom the default zoom level of the home point.
      */
-    void  home(double &lon, double &lat, int& zoom);
+    void  home(qreal &lon, qreal &lat, int& zoom);
     /**
      * @brief  Set the home point
      * @param  lon  the longitude of the new home point.
      * @param  lat  the latitude of the new home point.
      * @param  zoom the default zoom level for the new home point.
      */
-    void  setHome(const double lon, const double lat, const int zoom = 1050);
+    void  setHome(qreal lon, qreal lat, int zoom = 1050);
     /**
      * @brief  Set the home point
      * @param  homePoint  the new home point.
      * @param  zoom       the default zoom level for the new home point.
      */
-    void  setHome(const GeoDataPoint& homePoint, int zoom = 1050);
+    void  setHome(const GeoDataCoordinates& homePoint, int zoom = 1050);
 
     /**
      * @brief  Move left by the moveStep.
@@ -618,12 +609,26 @@ class MARBLE_EXPORT MarbleMap : public QObject
      */
     void setShowClouds( bool visible );
 
+    /**
+     * @brief Set whether the is tile is visible
+     * NOTE: This is part of the transitional debug API
+     *       and might be subject to changes until Marble 0.8
+     * @param visible visibility of the tile
+     */ 
+    void setShowTileId( bool visible );
+
     /**
      * @brief  Set whether the atmospheric glow is visible
      * @param  visible  visibility of the atmospheric glow
      */
     void setShowAtmosphere( bool visible );
 
+    /**
+     * @brief  Set whether the crosshairs are visible
+     * @param  visible  visibility of the crosshairs
+     */
+    void setShowCrosshairs( bool visible );
+
     /**
      * @brief  Set whether the coordinate grid overlay is visible
      * @param  visible  visibility of the coordinate grid
@@ -707,7 +712,7 @@ class MARBLE_EXPORT MarbleMap : public QObject
      * @param lat the new latitude value
      * @param lon the new longitude value
      */
-    void changeCurrentPosition( double lon, double lat );
+    void changeCurrentPosition( qreal lon, qreal lat );
 
      /**
      * @brief used to notify about the position of the mouse click
@@ -737,7 +742,7 @@ class MARBLE_EXPORT MarbleMap : public QObject
     void clearPersistentTileCache();
     /**
      * @brief  Set the limit of the persistent (on hard disc) tile cache.
-     * @param  bytes The limit in kilobytes.
+     * @param  bytes The limit in kilobytes, 0 means no limit.
      */
     void setPersistentTileCacheLimit( quint64 kiloBytes );
 
@@ -753,23 +758,6 @@ class MARBLE_EXPORT MarbleMap : public QObject
      */
     void updateChangedMap();
 
-    /**
-     * @brief update part of the map as defined in the BoundingBox
-     */
-    void updateRegion( BoundingBox& );
-
-    /**
-     * @brief Set the download url to load missing tiles
-     * @param url the url string
-     */
-    void setDownloadUrl( const QString &url );
-
-    /**
-     * @brief Set the download url to load missing tiles
-     * @param url the url objects
-     */
-    void setDownloadUrl( const QUrl &url );
-
     bool mapCoversViewport();
 
     Marble::AngleUnit defaultAngleUnit() const;
@@ -797,11 +785,11 @@ class MARBLE_EXPORT MarbleMap : public QObject
 
     void  mouseMoveGeoPosition( QString );
 
-    void  mouseClickGeoPosition( double lon, double lat, GeoDataPoint::Unit );
+    void  mouseClickGeoPosition( qreal lon, qreal lat, GeoDataCoordinates::Unit );
 
     void  timeout();
 
-    void  framesPerSecond( double fps );
+    void  framesPerSecond( qreal fps );
 
  protected:
 
@@ -817,5 +805,6 @@ class MARBLE_EXPORT MarbleMap : public QObject
     MarbleMapPrivate  * const d;
 };
 
+}
 
 #endif // MARBLEMAP_H
