@@ -30,7 +30,7 @@
 
 #include <QtCore/QList>
 #include <QtCore/QObject>
-#include <QtCore/QPersistentModelIndex>
+#include <QtCore/QModelIndex>
 #include <QtCore/QString>
 #include <QtCore/QVector>
 
@@ -45,15 +45,16 @@ class QRect;
 namespace Marble
 {
 
+class AbstractDataPlugin;
+class AbstractDataPluginItem;
 class AbstractScanlineTextureMapper;
-class BoundingBox;
 class GeoPainter;
 class FileViewModel;
 class GpsLayer;
 class GpxFileModel;
 class HttpDownloadManager;
 class MarbleModelPrivate;
-class PlaceMarkLayout;
+class PlacemarkLayout;
 class ExtDateTime;
 class SunLocator;
 class TextureColorizer;
@@ -62,11 +63,12 @@ class VectorComposer;
 class ViewParams;
 class TextureTile;
 class MergedLayerDecorator;
-class MarbleRenderPlugin;
-class MarbleAbstractFloatItem;
+class RenderPlugin;
+class AbstractFloatItem;
 class GeoDataDocument;
 class GeoSceneDocument;
 class GeoSceneTexture;
+class Planet;
 
 /**
  * @short The data model (not based on QAbstractModel) for a MarbleWidget.
@@ -132,11 +134,11 @@ class MARBLE_EXPORT MarbleModel : public QObject
                      bool redrawBackground, const QRect& dirtyRect);
 
     /**
-     * @brief Return the list of PlaceMarks as a QAbstractItemModel *
-     * @return a list of all PlaceMarks in the MarbleModel.
+     * @brief Return the list of Placemarks as a QAbstractItemModel *
+     * @return a list of all Placemarks in the MarbleModel.
      */
-    QAbstractItemModel*  placeMarkModel() const;
-    QItemSelectionModel* placeMarkSelectionModel() const;
+    QAbstractItemModel*  placemarkModel() const;
+    QItemSelectionModel* placemarkSelectionModel() const;
     QAbstractItemModel*  geometryModel() const;
 
     /**
@@ -156,15 +158,14 @@ class MARBLE_EXPORT MarbleModel : public QObject
     /**
      * @brief Set a new map theme to use.
      * @param selectedMap  the identifier of the selected map theme
-     * @param parent       the parent widget
      * @param currentProjection  the current projection
      *
      * This function sets the map theme, i.e. combination of tile set
      * and color scheme to use.  If the map theme is not previously
      * used, some basic tiles are created and a progress dialog is
-     * shown.  This is what the parent parameter is used for.
+     * shown.
      *
-     * NOTE: Both the parent and currentProjection parameters will
+     * NOTE: The currentProjection parameters will
      *       disappear soon.
      *
      * The ID of the new maptheme. To ensure that a unique 
@@ -200,13 +201,13 @@ class MARBLE_EXPORT MarbleModel : public QObject
      */
     void setDownloadManager( HttpDownloadManager *downloadManager );
 
-    void addPlaceMarkFile( const QString& filename );
-    void addPlaceMarkData( const QString& data, const QString& key = "data" );
-    void removePlaceMarkKey( const QString& key );
+    void addPlacemarkFile( const QString& filename );
+    void addPlacemarkData( const QString& data, const QString& key = "data" );
+    void removePlacemarkKey( const QString& key );
 
-    QVector<QPersistentModelIndex> whichFeatureAt( const QPoint& ) const;
+    QVector<QModelIndex> whichFeatureAt( const QPoint& ) const;
 
-    PlaceMarkLayout    *placeMarkLayout()   const;
+    PlacemarkLayout    *placemarkLayout()   const;
     VectorComposer     *vectorComposer()     const;
     /**
      * @brief Returns the map's TextureColorizer
@@ -261,8 +262,38 @@ class MARBLE_EXPORT MarbleModel : public QObject
      */
     quint64 volatileTileCacheLimit() const;
 
-    QList<MarbleRenderPlugin *>      renderPlugins() const;
-    QList<MarbleAbstractFloatItem *> floatItems() const;
+    /**
+     * @brief Returns a list of all RenderPlugins in the model, this includes float items
+     * @return the list of RenderPlugins
+     */
+    QList<RenderPlugin *>      renderPlugins() const;
+    /**
+     * @brief Returns a list of all FloatItems in the model
+     * @return the list of the floatItems
+     */
+    QList<AbstractFloatItem *> floatItems()    const;
+    /**
+     * @brief Returns a list of all DataPlugins on the layer
+     * @return the list of DataPlugins
+     */
+    QList<AbstractDataPlugin *> dataPlugins()  const;
+    
+    /**
+     * @brief Returns all widgets of dataPlugins on the position curpos 
+     */
+    QList<AbstractDataPluginItem *> whichItemAt( const QPoint& curpos ) const;
+
+    /**
+     * @brief Returns the planet object for the current map.
+     * @return the planet object for the current map
+     */
+    Planet* planet() const;
+
+    /**
+     * @brief Return the current tile zoom level. For example for OpenStreetMap
+     *        possible values are 1..18, for BlueMarble 0..6.
+     */
+    int tileZoomLevel() const;
 
  public Q_SLOTS:
     void clearVolatileTileCache();
@@ -296,7 +327,7 @@ class MARBLE_EXPORT MarbleModel : public QObject
 
     /**
      * @brief Signal that the map theme has changed, and to which theme.
-     * @param name the identifier of the new map theme.
+     * @param mapTheme the identifier of the new map theme.
      * @see  mapTheme
      * @see  setMapTheme
      */
@@ -305,14 +336,6 @@ class MARBLE_EXPORT MarbleModel : public QObject
      * @brief Signal that the MarbleModel has changed in general
      */
     void modelChanged();
-    /**
-     * @brief Signal that a region of the earth has changed
-     * @param rect the region that changed.
-     *
-     * This is currently used only for gpx files, but will likely be
-     * used for more things in the future.
-     */
-    void regionChanged( BoundingBox &rect );
 
     /**
      * @brief Signal that a timer has gone off.
@@ -327,8 +350,7 @@ class MARBLE_EXPORT MarbleModel : public QObject
     MarbleModelPrivate  * const d;
 
     Q_PRIVATE_SLOT( d, void notifyModelChanged() )
-    Q_PRIVATE_SLOT( d, void geoDataDocumentLoaded( GeoDataDocument& ) )
-    Q_PRIVATE_SLOT( d, void geoDataDocumentAdded( GeoDataDocument* ) )
+    Q_PRIVATE_SLOT( d, void geoDataDocumentAdded( const GeoDataDocument& ) )
 };
 
 }
