@@ -28,11 +28,10 @@
 #include <QtGui/QPixmap>
 #include <QtDesigner/QDesignerExportWidget>
 
-//#include <QtDBus/QtDBus>
-
 #include "marble_export.h"
 #include "GeoDataCoordinates.h"       // In geodata/data/
 #include "MarbleWidgetInputHandler.h"
+#include "Quaternion.h"
 #include "global.h"             // types needed in all of marble.
 
 // Qt
@@ -49,17 +48,15 @@ namespace Marble
 class MarbleWidgetPrivate;
 
 // Marble
-class BoundingBox;
 class MarbleMap;
 class MarbleModel;
-class HttpDownloadManager;
 class TileCreator;
 class SunLocator;
 class GpxFileModel;
 class FileViewModel;
 class GeoPainter;
-class MarbleRenderPlugin;
-class MarbleAbstractFloatItem;
+class RenderPlugin;
+class AbstractFloatItem;
 class GeoSceneDocument;
 
 /**
@@ -115,7 +112,9 @@ class GeoSceneDocument;
 class MARBLE_EXPORT MarbleWidget : public QWidget
 {
     Q_OBJECT
-    Q_CLASSINFO("D-Bus Interface", "org.kde.marble")
+#ifdef MARBLE_DBUS
+    Q_CLASSINFO("D-Bus Interface", "org.kde.MarbleWidget")
+#endif
 
     Q_PROPERTY(int zoom          READ zoom            WRITE zoomView)
 
@@ -190,24 +189,15 @@ class MARBLE_EXPORT MarbleWidget : public QWidget
      */
     void setInputHandler(MarbleWidgetInputHandler *handler);
 
-    /**
-     * @brief Set the download manager to load missing tiles
-     * @param manager the manager instance
-     *
-     * The instance will be destructed by MarbleWidget when not
-     * used any longer.
-     */
-    void setDownloadManager( HttpDownloadManager *downloadManager );
-
     /**
      * @brief Return the active region in which it's possible to drag the view using the mouse.
      */
     const QRegion  activeRegion();
 
     /**
-     * @brief Return the active region in which it's possible to drag the view using the mouse.
+     * @brief Return the projected region which describes the (shape of the) projected surface.
      */
-    const QRegion  projectedRegion();
+    const QRegion  mapRegion();
 
     /**
      * @brief  Return the radius of the globe in pixels.
@@ -221,7 +211,7 @@ class MARBLE_EXPORT MarbleWidget : public QWidget
     void        setRadius(int radius);
 
     /**
-     * @brief Return the current zoom level.
+     * @brief Return the current zoom amount.
      */
     int         zoom() const;
 
@@ -270,7 +260,7 @@ class MARBLE_EXPORT MarbleWidget : public QWidget
      *         @c false if the geographical coordinates are not visible on the screen
      */
     bool screenCoordinates( qreal lon, qreal lat,
-                            int& x, int& y );
+                            qreal& x, qreal& y );
 
     /**
      * @brief Get the Y coordinate of the North Pole.
@@ -291,18 +281,6 @@ class MARBLE_EXPORT MarbleWidget : public QWidget
                          qreal& lon, qreal& lat,
                          GeoDataCoordinates::Unit = GeoDataCoordinates::Degree );
 
-    /**
-     * @brief Get a quaternion representing a point on the earth corresponding to a pixel in the widget.
-     * @param x  the x coordinate of the pixel
-     * @param y  the y coordinate of the pixel
-     * @param q  the out parameter where the result is returned
-     * @return @c true  if the pixel (x, y) is within the globe
-     *         @c false if the pixel (x, y) is outside the globe, i.e. in space
-     */
-    bool    globalQuaternion( int x, int y, Quaternion &q);
-    // FIXME: Make the names of globalQuaternion() and
-    //        geoCoordinates() follow a pattern.
-
     /**
      * @brief Return the longitude of the center point.
      */
@@ -316,12 +294,12 @@ class MARBLE_EXPORT MarbleWidget : public QWidget
     /**
      * @brief Returns the model for all the placemarks on the globe.
      */
-    QAbstractItemModel *placeMarkModel() const;
+    QAbstractItemModel *placemarkModel() const;
 
     /**
      * @brief Returns the selection model for all the placemarks on the globe.
      */
-    QItemSelectionModel *placeMarkSelectionModel() const;
+    QItemSelectionModel *placemarkSelectionModel() const;
 
     /**
      * @brief  Return how much the map will move if one of the move slots are called.
@@ -331,22 +309,22 @@ class MARBLE_EXPORT MarbleWidget : public QWidget
 
     /**
      * @brief  Add a GeoDataPlacemark file to the model.
-     * @param  filename  the filename of the file containing the PlaceMarks.
+     * @param  filename  the filename of the file containing the Placemarks.
      */
-    void addPlaceMarkFile( const QString &filename );
+    void addPlacemarkFile( const QString &filename );
 
     /**
      * @brief  Add GeoDataPlacemark data as string to the model.
-     * @param  data  the string containing the PlaceMarks.
+     * @param  data  the string containing the Placemarks.
      * @param key  the string needed to identify the data
      */
-    void addPlaceMarkData( const QString& data, const QString& key = "data" );
+    void addPlacemarkData( const QString& data, const QString& key = "data" );
     
     /**
      * @brief  remove data or files from the model.
-     * @param key  either the filename or the string used to identify the data in addPlaceMarkFile and addPlaceMarkData
+     * @param key  either the filename or the string used to identify the data in addPlacemarkFile and addPlacemarkData
      */
-    void removePlaceMarkKey( const QString& key );
+    void removePlacemarkKey( const QString& key );
 
     /**
      * @brief  Return the quaternion that specifies the rotation of the globe.
@@ -487,12 +465,22 @@ class MARBLE_EXPORT MarbleWidget : public QWidget
 
     SunLocator* sunLocator();
 
-    void setProxy( const QString& proxyHost, const quint16 proxyPort );
+    void setProxy( const QString& proxyHost, const quint16 proxyPort, const QString& user, const QString& password );
     QString proxyHost() const;
     quint16 proxyPort() const;
+    QString user() const;
+    QString password() const;
 
-    QList<MarbleRenderPlugin *>      renderPlugins() const;
-    QList<MarbleAbstractFloatItem *> floatItems()    const;
+    /**
+     * @brief Returns a list of all RenderPlugins on the widget, this includes float items
+     * @return the list of RenderPlugins
+     */
+    QList<RenderPlugin *>      renderPlugins() const;
+    /**
+     * @brief Returns a list of all FloatItems on the widget
+     * @return the list of the floatItems
+     */
+    QList<AbstractFloatItem *> floatItems()    const;
 
 
     /**
@@ -518,17 +506,17 @@ class MARBLE_EXPORT MarbleWidget : public QWidget
     /**
      * @brief Get the GeoSceneDocument object of the current map theme
      */
-    Marble::GeoSceneDocument *mapTheme() const;
+    Marble::GeoSceneDocument * mapTheme() const;
 
     /**
      * @brief Return a QAbstractItemModel containing GPX files.
      */
-    GpxFileModel  *gpxFileModel();
+    GpxFileModel * gpxFileModel();
 
     /**
      * @brief Return a QAbstractItemModel containing files.
      */
-    FileViewModel* fileViewModel() const;
+    FileViewModel * fileViewModel() const;
 
     /**
      * @brief Retrieve the map quality depending on the view context 
@@ -821,11 +809,20 @@ class MARBLE_EXPORT MarbleWidget : public QWidget
      */
     void setShowFrameRate( bool visible );
 
+    /**
+     * @brief Set whether the is tile is visible
+     * NOTE: This is part of the transitional debug API
+     *       and might be subject to changes until Marble 0.8
+     * @param visible visibility of the tile
+     */
+    void setShowTileId( bool visible);
+
     /**
      * @brief Set the current Gps position
      * @param lat the new latitude value
      * @param lon the new longitude value
      */
+    
     void changeCurrentPosition( qreal lon, qreal lat );
 
      /**
@@ -846,7 +843,7 @@ class MARBLE_EXPORT MarbleWidget : public QWidget
     void clearPersistentTileCache();
     /**
      * @brief  Set the limit of the persistent (on hard disc) tile cache.
-     * @param  kilobytes The limit in kilobytes.
+     * @param  kilobytes The limit in kilobytes, 0 means no limit.
      */
     void setPersistentTileCacheLimit( quint64 kiloBytes );
 
@@ -882,23 +879,6 @@ class MARBLE_EXPORT MarbleWidget : public QWidget
      */
     void updateChangedMap();
 
-    /**
-     * @brief Update part of the map as defined in the BoundingBox
-     */
-    void updateRegion( BoundingBox& );
-
-    /**
-     * @brief Set the download url to load missing tiles
-     * @param url the url string
-     */
-    void setDownloadUrl( const QString &url );
-
-    /**
-     * @brief Set the download url to load missing tiles
-     * @param url the url objects
-     */
-    void setDownloadUrl( const QUrl &url );
-
     /**
      * @brief Set the map quality depending on the view context 
      */
