@@ -12,49 +12,66 @@
 // Local
 #include "MercatorProjection.h"
 
+#include <QtCore/QDebug>
+
 // Marble
-#include "MercatorProjectionHelper.h"
 #include "ViewportParams.h"
+
 #include "MathHelper.h"
 #include "GeoDataPoint.h"
 
 using namespace Marble;
 
-static MercatorProjectionHelper  theHelper;
-
-
 MercatorProjection::MercatorProjection()
-    : AbstractProjection()
+    : AbstractProjection(),
+      d( 0 )
 {
-    // This is the max value where atanh( sin( lat ) ) is defined.
-    m_maxLat  = 85.05113 * DEG2RAD;
-    m_minLat  = -85.05113 * DEG2RAD;
-    m_traversableMaxLat = false;
-    m_repeatX = true;
+    setRepeatX( repeatableX() );
+    setMinLat( minValidLat() );
+    setMaxLat( maxValidLat() );
 }
 
 MercatorProjection::~MercatorProjection()
 {
 }
 
-
-AbstractProjectionHelper *MercatorProjection::helper()
+bool MercatorProjection::repeatableX() const
 {
-    return &theHelper;
+    return true;
 }
 
-
-bool MercatorProjection::screenCoordinates( const qreal lon, const qreal lat,
-                                            const ViewportParams *viewport,
-                                            int& x, int& y )
+qreal MercatorProjection::maxValidLat() const
 {
-    if ( fabs( lat ) > m_maxLat )
-        return false;
+    // This is the max value where atanh( sin( lat ) ) is defined.
+    return +85.05113 * DEG2RAD;
+}
+
+qreal MercatorProjection::minValidLat() const
+{
+    // This is the min value where atanh( sin( lat ) ) is defined.
+    return -85.05113 * DEG2RAD;
+}
+
+bool MercatorProjection::screenCoordinates( const qreal lon, const qreal _lat,
+                                            const ViewportParams *viewport,
+                                            qreal& x, qreal& y )
+{
+    bool retval = true;
+    qreal lat = _lat;
+    
+    if ( lat > maxLat() ) {
+        lat = maxLat();
+        retval = false;
+    }
+    if ( lat < minLat() ) {
+        lat = minLat();
+        retval = false;
+    }
 
     // Convenience variables
     int  radius = viewport->radius();
-    int  width  = viewport->width();
-    int  height = viewport->height();
+    qreal  width  = (qreal)(viewport->width());
+    qreal  height = (qreal)(viewport->height());
 
     qreal  rad2Pixel = 2 * radius / M_PI;
 
@@ -64,15 +81,18 @@ bool MercatorProjection::screenCoordinates( const qreal lon, const qreal lat,
     viewport->centerCoordinates( centerLon, centerLat );
 
     // Let (x, y) be the position on the screen of the placemark..
-    x = (int)( width  / 2 + rad2Pixel * ( lon - centerLon ) );
-    y = (int)( height / 2 - rad2Pixel * ( atanh( sin( lat ) ) - atanh( sin( centerLat ) ) ) );
+    x = ( width  / 2 + rad2Pixel * ( lon - centerLon ) );
+    y = ( height / 2 - rad2Pixel * ( atanh( sin( lat ) ) - atanh( sin( centerLat ) ) ) );
 
-    return true;
+    return retval && ( ( 0 <= y && y < height )
+                  && ( ( 0 <= x && x < width )
+                  || ( 0 <= x - 4 * radius && x - 4 * radius < width )
+                  || ( 0 <= x + 4 * radius && x + 4 * radius < width ) ) );
 }
 
 bool MercatorProjection::screenCoordinates( const GeoDataCoordinates &geopoint, 
                                             const ViewportParams *viewport,
-                                            int &x, int &y, bool &globeHidesPoint )
+                                            qreal &x, qreal &y, bool &globeHidesPoint )
 {
     globeHidesPoint = false;
     qreal  lon;
@@ -80,13 +100,26 @@ bool MercatorProjection::screenCoordinates( const GeoDataCoordinates &geopoint,
 
     geopoint.geoCoordinates( lon, lat );
 
-    if ( fabs( lat ) >  m_maxLat )
-        return false;
+    bool retval = true;
+
+    if ( lat > maxLat() ) {
+        GeoDataCoordinates approxCoords( geopoint );
+        approxCoords.setLatitude( maxLat() );
+        approxCoords.geoCoordinates( lon, lat );
+        retval = false;
+    }
+
+    if ( lat < minLat() ) {
+        GeoDataCoordinates approxCoords( geopoint );
+        approxCoords.setLatitude( minLat() );
+        approxCoords.geoCoordinates( lon, lat );
+        retval = false;
+    }
 
     // Convenience variables
     int  radius = viewport->radius();
-    int  width  = viewport->width();
-    int  height = viewport->height();
+    qreal  width  = (qreal)(viewport->width());
+    qreal  height = (qreal)(viewport->height());
 
     qreal  rad2Pixel = 2 * radius / M_PI;
 
@@ -95,20 +128,21 @@ bool MercatorProjection::screenCoordinates( const GeoDataCoordinates &geopoint,
     viewport->centerCoordinates( centerLon, centerLat );
     
     // Let (x, y) be the position on the screen of the placemark..
-    x = (int)( width  / 2 + rad2Pixel * ( lon - centerLon ) );
-    y = (int)( height / 2 - rad2Pixel * ( atanh( sin( lat ) ) - atanh( sin( centerLat ) ) ) );
+    x = ( width  / 2 + rad2Pixel * ( lon - centerLon ) );
+    y = ( height / 2 - rad2Pixel * ( atanh( sin( lat ) ) - atanh( sin( centerLat ) ) ) );
 
     // Return true if the calculated point is inside the screen area,
     // otherwise return false.
-    return ( ( 0 <= y && y < height )
-             && ( ( 0 <= x && x < width )
+    return retval && ( ( 0 <= y && y < height )
+                  && ( ( 0 <= x && x < width )
                   || ( 0 <= x - 4 * radius && x - 4 * radius < width )
                   || ( 0 <= x + 4 * radius && x + 4 * radius < width ) ) );
 }
 
 bool MercatorProjection::screenCoordinates( const GeoDataCoordinates &coordinates,
                                             const ViewportParams *viewport,
-                                            int *x, int &y, int &pointRepeatNum,
+                                            qreal *x, qreal &y, int &pointRepeatNum,
+                                            const QSizeF& size,
                                             bool &globeHidesPoint )
 {
     // On flat projections the observer's view onto the point won't be 
@@ -120,13 +154,26 @@ bool MercatorProjection::screenCoordinates( const GeoDataCoordinates &coordinate
 
     coordinates.geoCoordinates( lon, lat );
 
-    if ( fabs( lat ) > maxLat() )
-        return false;
+    bool retval = true;
+
+    if ( lat > maxLat() ) {
+        GeoDataCoordinates approxCoords( coordinates );
+        approxCoords.setLatitude( maxLat() );
+        approxCoords.geoCoordinates( lon, lat );
+        retval = false;
+    }
+
+    if ( lat < minLat() ) {
+        GeoDataCoordinates approxCoords( coordinates );
+        approxCoords.setLatitude( minLat() );
+        approxCoords.geoCoordinates( lon, lat );
+        retval = false;
+    }
 
     // Convenience variables
     int  radius = viewport->radius();
-    int  width  = viewport->width();
-    int  height = viewport->height();
+    qreal  width  = (qreal)(viewport->width());
+    qreal  height = (qreal)(viewport->height());
 
     qreal  rad2Pixel = 2.0 * radius / M_PI;
 
@@ -135,16 +182,16 @@ bool MercatorProjection::screenCoordinates( const GeoDataCoordinates &coordinate
     viewport->centerCoordinates( centerLon, centerLat );
 
     // Let (itX, y) be the first guess for one possible position on screen..
-    int itX = (int)( width  / 2.0 + rad2Pixel * ( lon - centerLon ) );
-    y = (int)( height / 2 - rad2Pixel * ( atanh( sin( lat ) ) - atanh( sin( centerLat ) ) ) );
+    qreal itX = ( width  / 2.0 + rad2Pixel * ( lon - centerLon ) );
+    y = ( height / 2.0 - rad2Pixel * ( atanh( sin( lat ) ) - atanh( sin( centerLat ) ) ) );
 
     // Make sure that the requested point is within the visible y range:
-    if ( 0 <= y && y < height ) {
+    if ( 0 <= y + size.height() / 2.0 && y < height + size.height() / 2.0 ) {
         // First we deal with the case where the repetition doesn't happen
-        if ( m_repeatX == false ) {
+        if ( !repeatX() ) {
             *x = itX;
-            if ( 0 < itX && itX < width ) {
-                return true;
+            if ( 0 < itX + size.width() / 2.0  && itX < width + size.width() / 2.0 ) {
+                return retval && true;
             }
             else {
                 // the requested point is out of the visible x range:
@@ -158,21 +205,21 @@ bool MercatorProjection::screenCoordinates( const GeoDataCoordinates &coordinate
 
         // Finding the leftmost positive x value
         if ( itX > xRepeatDistance ) {
-            itX %= xRepeatDistance;
+            int repeatNum = (int)( itX / xRepeatDistance );  
+            itX = itX - repeatNum * xRepeatDistance;
         }
-        if ( itX < 0 ) {
+        if ( itX + size.width() / 2.0 < 0 ) {
             itX += xRepeatDistance;
         }
         // the requested point is out of the visible x range:
-        if ( itX > width ) {
+        if ( itX > width + size.width() / 2.0 ) {
             return false;
         }
 
         // Now iterate through all visible x screen coordinates for the point 
         // from left to right.
         int itNum = 0;
-
-        while ( itX < width ) {
+        while ( itX - size.width() / 2.0 < width ) {
             *x = itX;
             ++x;
             ++itNum;
@@ -181,166 +228,23 @@ bool MercatorProjection::screenCoordinates( const GeoDataCoordinates &coordinate
 
         pointRepeatNum = itNum;
 
-        return true;
+        return retval && true;
     }
 
     // the requested point is out of the visible y range:
     return false;
 }
 
-bool MercatorProjection::screenCoordinates( const GeoDataLineString &lineString, 
-                                    const ViewportParams *viewport,
-                                    QVector<QPolygonF *> &polygons )
+
+bool MercatorProjection::screenCoordinates( const GeoDataLineString &lineString,
+                                            const ViewportParams *viewport,
+                                            QVector<QPolygonF *> &polygons )
 {
-    // Compare bounding box size of the line string with the angularResolution
-    // Immediately return if the latLonAltBox is smaller.
-
-    if ( !viewport->resolves( lineString.latLonAltBox() ) ) {
-//      qDebug() << "Object too small to be resolved";
-        return false;
-    }
-
-    int x = 0;
-    int y = 0;
-    bool globeHidesPoint = false;
-    bool isVisible = false;
-
-    int previousX = -1; 
-    int previousY = -1;
-    bool previousGlobeHidesPoint = false;
-    bool previousIsVisible = false;
-
-    QPolygonF  *polygon = new QPolygonF;
-    
-    GeoDataLineString::ConstIterator itCoords = lineString.constBegin();
-    GeoDataLineString::ConstIterator itPreviousCoords = lineString.constBegin();
-
-    GeoDataCoordinates previousCoords;
-    GeoDataCoordinates currentCoords;
-
-    GeoDataLineString::ConstIterator itEnd = lineString.constEnd();
-
-    bool processingLastNode = false;
-
-    // We use a while loop to be able to cover linestrings as well as linear rings:
-    // Linear rings require to tessellate the path from the last node to the first node
-    // which isn't really convenient to achieve with a for loop ...
-
-    const qreal precision = 20.0;
-    const bool isLong = lineString.size() > 50;
-
-    while ( itCoords != itEnd )
-    {
-        // Optimization for line strings with a big amount of nodes
-        bool skipNode = isLong && viewport->resolves( **itPreviousCoords, **itCoords); 
-
-        if ( !skipNode ) {
-
-            previousCoords = **itPreviousCoords;
-            currentCoords  = **itCoords;
-
-            isVisible = screenCoordinates( currentCoords, viewport, x, y, globeHidesPoint );
-
-            // Initializing variables that store the values of the previous iteration
-            if ( !processingLastNode && itCoords == lineString.constBegin() ) {
-                previousGlobeHidesPoint = globeHidesPoint;
-                previousIsVisible = isVisible;
-                itPreviousCoords = itCoords;
-                previousX = x;
-                previousY = y;
-            }
-
-            // TODO: on flat maps we need to take the date line into account right here.
-
-            // This if-clause contains the section that tessellates the line 
-            // segments of a linestring. If you are about to learn how the code of 
-            // this class works you can safely ignore this section for a start.
-
-            if ( lineString.tessellate() && ( isVisible || previousIsVisible ) ) {
-                // let the line segment follow the spherical surface
-                // if the distance between the previous point and the current point 
-                // on screen is too big
-
-                // We take the manhattan length as a distance approximation
-                // that can be too big by a factor of sqrt(2)
-                qreal distance = fabs((qreal)(x - previousX)) + fabs((qreal)(y - previousY));
-
-                // FIXME: This is a work around: remove as soon as we handle horizon crossing
-                if ( globeHidesPoint || previousGlobeHidesPoint ) {
-                    distance = 350;
-                }
-
-                const qreal safeDistance = - 0.5 * distance;
-
-                // Interpolate additional nodes if the current or previous nodes are visible
-                // or if the line segment that connects them might cross the viewport.
-                // The latter can pretty safely be excluded for most projections if both points 
-                // are located on the same side relative to the viewport boundaries and if they are 
-                // located more than half the line segment distance away from the viewport.
-
-                if (   !( x < safeDistance && previousX < safeDistance )
-                    || !( y < safeDistance && previousY < safeDistance )
-                    || !( x + safeDistance > viewport->width() 
-                        && previousX + safeDistance > viewport->width() )
-                    || !( y + safeDistance > viewport->height()
-                        && previousY + safeDistance > viewport->height() )
-                ){
-                    int suggestedCount = (int)( distance / precision );
-
-                    if ( distance > precision ) {
-    //                    qDebug() << "Distance: " << distance;
-                        *polygon << tessellateLineSegment( previousCoords, currentCoords, 
-                                                        suggestedCount, viewport,
-                                                        lineString.tessellationFlags() );
-                    }
-                }
-            }
-
-            if ( !globeHidesPoint ) {
-                polygon->append( QPointF( x, y ) );
-            }
-            else {
-                if (   !previousGlobeHidesPoint 
-                    && !lineString.isClosed() // FIXME: this probably needs to take rotation 
-                                                //        into account for some cases
-                    ) {
-                    polygons.append( polygon );
-                    polygon = new QPolygonF;
-                }
-            }
-
-            previousGlobeHidesPoint = globeHidesPoint;
-            previousIsVisible = isVisible;
-            itPreviousCoords = itCoords;
-            previousX = x;
-            previousY = y;
-        }
-
-        // Here we modify the condition to be able to process the 
-        // first node after the last node in a LinearRing.
-
-        if ( processingLastNode ) {
-            break;
-        }
-        ++itCoords;
-
-        if ( itCoords == itEnd  && lineString.isClosed() ) {
-            itCoords = lineString.constBegin();
-            processingLastNode = true;
-        }        
-    }
-
-    if ( polygon->size() > 1 ){
-        polygons.append( polygon );
-    }
-    else {
-        delete polygon;
-    }
-
-    return polygons.isEmpty();
+    return AbstractProjection::screenCoordinates( lineString, viewport, polygons );
 }
 
-bool MercatorProjection::geoCoordinates( int x, int y,
+
+bool MercatorProjection::geoCoordinates( const int x, const int y,
                                          const ViewportParams *viewport,
                                          qreal& lon, qreal& lat,
                                          GeoDataCoordinates::Unit unit )
@@ -397,9 +301,9 @@ GeoDataLatLonAltBox MercatorProjection::latLonAltBox( const QRect& screenRect,
 
     // If the whole globe is visible we can easily calculate
     // analytically the lon-/lat- range.
-    qreal pitch = GeoDataPoint::normalizeLat( viewport->planetAxis().pitch() );
+    // qreal pitch = GeoDataPoint::normalizeLat( viewport->planetAxis().pitch() );
 
-    if ( m_repeatX ) {
+    if ( repeatX() ) {
         int xRepeatDistance = 4 * viewport->radius();
         if ( viewport->width() >= xRepeatDistance ) {
             latLonAltBox.setWest( -M_PI );
@@ -414,7 +318,7 @@ GeoDataLatLonAltBox MercatorProjection::latLonAltBox( const QRect& screenRect,
         GeoDataCoordinates maxLonPoint( +M_PI, averageLatitude, GeoDataCoordinates::Radian );
         GeoDataCoordinates minLonPoint( -M_PI, averageLatitude, GeoDataCoordinates::Radian );
     
-        int dummyX, dummyY; // not needed
+        qreal dummyX, dummyY; // not needed
         bool dummyVal;
     
         if ( screenCoordinates( maxLonPoint, viewport, dummyX, dummyY, dummyVal ) ) {
@@ -453,3 +357,41 @@ bool MercatorProjection::mapCoversViewport( const ViewportParams *viewport ) con
 
     return true;
 }
+
+QPainterPath MercatorProjection::mapShape( const ViewportParams *viewport ) const
+{
+    // Convenience variables
+    //int  radius = viewport->radius();
+    int  width  = viewport->width();
+    int  height = viewport->height();
+
+    // Calculate translation of center point
+    qreal  centerLon;
+    qreal  centerLat;
+    viewport->centerCoordinates( centerLon, centerLat );
+
+    qreal  yTop;
+    qreal  yBottom;
+    qreal  xDummy;
+    AbstractProjection *proj = viewport->currentProjection();
+
+    // Get the top and bottom y coordinates of the projected map.
+    proj->screenCoordinates( 0.0, proj->maxLat(), viewport,
+                 xDummy, yTop );
+    proj->screenCoordinates( 0.0, proj->minLat(), viewport,
+                 xDummy, yBottom );
+
+    if ( yTop < 0 )
+        yTop = 0;
+    if ( yBottom > height )
+        yBottom =  height;
+
+    QPainterPath mapShape;
+    mapShape.addRect(
+                    0,
+                    yTop,
+                    width,
+                    yBottom - yTop );
+
+    return mapShape;
+}
