@@ -17,6 +17,7 @@
 #include <QtCore/QDebug>
 #include <QtCore/QFile>
 #include <QtCore/QString>
+#include <QtCore/QTime>
 #include <QtGui/QColor>
 #include <QtGui/QImage>
 #include <QtGui/QPainter>
@@ -27,27 +28,19 @@
 #include "ViewParams.h"
 #include "ViewportParams.h"
 #include "AbstractProjection.h"
+#include "MathHelper.h"
 
-#ifdef Q_CC_MSVC
-#include <float.h>
-static double msvc_asinh(double x)
-{
-  if ( _isnan ( x ) ) {
-    errno = EDOM;
-    return x;
-  }
-
-  return ( log( x + sqrt ( x * x + 1.0 ) ) );
-}
-#define asinh msvc_asinh
-#endif
+using namespace Marble;
 
 uint TextureColorizer::texturepalette[16][512];
 
 TextureColorizer::TextureColorizer( const QString& seafile, 
                                     const QString& landfile )
 {
-   generatePalette(seafile, landfile);
+    QTime t;
+    t.start();
+    generatePalette(seafile, landfile);
+    qDebug("TextureColorizer: Time elapsed: %d ms", t.elapsed());
 }
 
 QString TextureColorizer::seafile() const
@@ -113,11 +106,11 @@ void TextureColorizer::colorize(ViewParams *viewParams)
             || viewParams->projection() == Mercator )
         {
             // Calculate translation of center point
-            double  centerLon;
-            double  centerLat;
+            qreal  centerLon;
+            qreal  centerLat;
             viewParams->centerCoordinates( centerLon, centerLat );
 
-            const float rad2Pixel = (double)( 2 * radius ) / M_PI;
+            const float rad2Pixel = (qreal)( 2 * radius ) / M_PI;
             if ( viewParams->projection() == Equirectangular ) {
                 int yCenterOffset = (int)( centerLat * rad2Pixel );
                 yTop = ( imgry - radius + yCenterOffset < 0)? 0 : imgry - radius + yCenterOffset;
@@ -130,7 +123,9 @@ void TextureColorizer::colorize(ViewParams *viewParams)
             }
         }
 
-        for (int y = yTop; y < yBottom; ++y) {
+        const int itEnd = yBottom;
+
+        for (int y = yTop; y < itEnd; ++y) {
 
             QRgb  *writeData         = (QRgb*)( origimg->scanLine( y ) );
             const QRgb  *coastData   = (QRgb*)( coastimg->scanLine( y ) );
@@ -139,14 +134,14 @@ void TextureColorizer::colorize(ViewParams *viewParams)
             const uchar *readDataEnd = readDataStart + imgwidth*4;
 
             emboss.buffer = 0;
-		
+        
             for ( uchar* readData = readDataStart; 
-		  readData < readDataEnd; 
-		  readData += 4, ++writeData, ++coastData )
-	    {
+                  readData < readDataEnd;
+                  readData += 4, ++writeData, ++coastData )
+            {
 
                 // Cheap Emboss / Bumpmapping
-                const uchar&  grey = *readData; // qBlue(*data);
+                uchar&  grey = *readData; // qBlue(*data);
 
                 if ( showRelief ) {
                     emboss.gpuint.x4 = grey;
@@ -169,7 +164,7 @@ void TextureColorizer::colorize(ViewParams *viewParams)
                     }
                 }
                 else {
-                    double c = 1.0 / 255.0;
+                    qreal c = 1.0 / 255.0;
 
                     if ( qRed( *coastData ) != 0 && qGreen( *coastData ) == 0) {
 
@@ -212,7 +207,7 @@ void TextureColorizer::colorize(ViewParams *viewParams)
 
         for ( int y = yTop; y < yBottom; ++y ) {
             const int  dy = imgry - y;
-            int  rx = (int)sqrt( (double)( radius * radius - dy * dy ) );
+            int  rx = (int)sqrt( (qreal)( radius * radius - dy * dy ) );
             int  xLeft  = 0; 
             int  xRight = imgwidth;
 
@@ -229,18 +224,17 @@ void TextureColorizer::colorize(ViewParams *viewParams)
 
  
             for ( uchar* readData = readDataStart;
-		  readData < readDataEnd;
-		  readData += 4, ++writeData, ++coastData )
-	    {
+                  readData < readDataEnd;
+                  readData += 4, ++writeData, ++coastData )
+            {
                 // Cheap Embosss / Bumpmapping
 
-                const uchar& grey = *readData; // qBlue(*data);
+                uchar& grey = *readData; // qBlue(*data);
 
-                if ( showRelief == true ) {
+                if ( showRelief ) {
                     emboss.buffer = emboss.buffer >> 8;
                     emboss.gpuint.x4 = grey;    
                     bump = ( emboss.gpuint.x1 + 16 - grey ) >> 1;
-
                     if ( bump > 15 ) bump = 15;
                     if ( bump < 0 )  bump = 0;
                 }
@@ -258,7 +252,7 @@ void TextureColorizer::colorize(ViewParams *viewParams)
                     }
                 }
                 else {
-                    double c = 1.0 / 255.0;
+                    qreal c = 1.0 / 255.0;
 
                     if ( qRed( *coastData ) != 0 && qGreen( *coastData ) == 0) {
 
@@ -298,19 +292,16 @@ void TextureColorizer::colorize(ViewParams *viewParams)
 }
 
 void TextureColorizer::generatePalette(const QString& seafile,
-				       const QString& landfile)
+                                       const QString& landfile)
 {
-    for(int i = 0; i < 16; i++) {
-        for(int j = 0; j < 512; j++) {
-            texturepalette[i][j] = 0;
-        }
-    }
-    QImage   gradientImage ( 256, 10, QImage::Format_RGB32 );
+    QImage   gradientImage ( 256, 3, QImage::Format_RGB32 );
     QPainter  gradientPainter;
     gradientPainter.begin( &gradientImage );
     gradientPainter.setPen( Qt::NoPen );
 
-    QImage    shadingImage ( 256, 10, QImage::Format_RGB32 );
+
+    int shadingStart = 120;
+    QImage    shadingImage ( 16, 3, QImage::Format_RGB32 );
     QPainter  shadingPainter;
     shadingPainter.begin( &shadingImage );
     shadingPainter.setPen( Qt::NoPen );
@@ -327,43 +318,48 @@ void TextureColorizer::generatePalette(const QString& seafile,
         QFile  file( filename );
         file.open( QIODevice::ReadOnly );
         QTextStream  stream( &file );  // read the data from the file
+
         QString      evalstrg;
 
         while ( !stream.atEnd() ) {
             stream >> evalstrg;
-            if ( !evalstrg.isEmpty() && evalstrg.contains( "=" ) ) {
-                QString  colorValue = evalstrg.section( "=", 0, 0 );
-                QString  colorPosition = evalstrg.section( "=", 1, 1 );
+            if ( !evalstrg.isEmpty() && evalstrg.contains( '=' ) ) {
+                QString  colorValue = evalstrg.left( evalstrg.indexOf( '=' ) );
+                QString  colorPosition = evalstrg.mid( evalstrg.indexOf( '=' ) + 1 );
                 gradient.setColorAt( colorPosition.toDouble(),
-				     QColor( colorValue ) );
+                                     QColor( colorValue ) );
             }
         }
         gradientPainter.setBrush( gradient );
-        gradientPainter.drawRect( 0, 0, 256, 3 );	
+        gradientPainter.drawRect( 0, 0, 256, 3 );        
 
-        for ( int j = 0; j < 16; ++j ) {
-  
-            int  shadeIndex = 120 + j;
+        QLinearGradient  shadeGradient( - shadingStart, 0, 256 - shadingStart, 0 );
 
-            for ( int i = 0; i < 256; ++i ) {
+        shadeGradient.setColorAt(0.00, QColor(Qt::white));
+        shadeGradient.setColorAt(0.15, QColor(Qt::white));
+        shadeGradient.setColorAt(0.75, QColor(Qt::black));
+        shadeGradient.setColorAt(1.00, QColor(Qt::black));
 
-                    QRgb  shadeColor = gradientImage.pixel( i, 1 );
-                    QLinearGradient  shadeGradient( 0, 0, 256, 0 );
-                    shadeGradient.setColorAt(0.15, QColor(Qt::white));
-                    shadeGradient.setColorAt(0.496, shadeColor);
-                    shadeGradient.setColorAt(0.504, shadeColor);
-                    shadeGradient.setColorAt(0.75, QColor(Qt::black));
-                    shadingPainter.setBrush( shadeGradient );
-                    shadingPainter.drawRect( 0, 0, 256, 3 );  
-                    QRgb  paletteColor = shadingImage.pixel( shadeIndex, 1 );
+        const QRgb * gradientScanLine  = (QRgb*)( gradientImage.scanLine( 1 ) );
+        const QRgb * shadingScanLine   = (QRgb*)( shadingImage.scanLine( 1 ) );
 
-                    // populate texturepalette[][]
-                    texturepalette[j][offset + i] = (uint)paletteColor;
+        for ( int i = 0; i < 256; ++i ) {
+
+            QRgb  shadeColor = *(gradientScanLine + i );
+            shadeGradient.setColorAt(0.496, shadeColor);
+            shadeGradient.setColorAt(0.504, shadeColor);
+            shadingPainter.setBrush( shadeGradient );
+            shadingPainter.drawRect( 0, 0, 16, 3 );  
+
+            // populate texturepalette[][]
+            for ( int j = 0; j < 16; ++j ) {
+                texturepalette[j][offset + i] = *(shadingScanLine + j );
             }
         }
+
         offset += 256;
     }
-    shadingPainter.end();  // Need to explicitely tell painter lifetime to avoid crash
+    shadingPainter.end();  // Need to explicitly tell painter lifetime to avoid crash
     gradientPainter.end(); // on some systems. 
 
     m_seafile = seafile;
