@@ -10,11 +10,14 @@
 //
 
 
-#include "GeoDataObject.h"
+#include "GeoDataDocument.h"
 
 #include <QtCore/QtGlobal>
 #include <QtCore/QDataStream>
 
+namespace Marble
+{
+
 class GeoDataObjectPrivate
 {
   public:
@@ -30,13 +33,13 @@ class GeoDataObjectPrivate
 
 GeoDataObject::GeoDataObject()
     : GeoNode(), Serializable(),
-      d( new GeoDataObjectPrivate )
+      d( new GeoDataObjectPrivate() )
 {
 }
 
 GeoDataObject::GeoDataObject( GeoDataObject const & other )
-    : GeoNode( other ), Serializable( other ),
-      d( new GeoDataObjectPrivate( *other.d ))
+    : Serializable( other ),
+      d( new GeoDataObjectPrivate( *other.d ) )
 {
 }
 
@@ -71,6 +74,27 @@ void GeoDataObject::setTargetId( int value )
     d->m_targetId = value;
 }
 
+GeoDataObject* GeoDataObject::child(int /* pos */ )
+{
+    return 0;
+}
+
+int GeoDataObject::row()
+{
+    return 0;
+}
+
+int GeoDataObject::childPosition( GeoDataObject *child )
+{
+    Q_UNUSED( child );
+    return 0;
+}
+
+int GeoDataObject::childCount()
+{
+    return 0;
+}
+
 void GeoDataObject::pack( QDataStream& stream ) const
 {
     stream << d->m_id;
@@ -82,3 +106,5 @@ void GeoDataObject::unpack( QDataStream& stream )
     stream >> d->m_id;
     stream >> d->m_targetId;
 }
+
+}
