@@ -169,8 +169,10 @@ void ParleyPlasma::createConfigurationInterface(KConfigDialog * parent)
     connect(parent, SIGNAL(okClicked()), this, SLOT(configAccepted()));
 
     connect( ui.fontSelectButton, SIGNAL(clicked()), this, SLOT(showFontSelectDlg()) );
+    connect( ui.updateIntervalSpinBox, SIGNAL(valueChanged(int)), this, SLOT(updateSpinBoxSuffix()) );
 
     ui.updateIntervalSpinBox->setValue(m_updateInterval/1000);
+    emit updateSpinBoxSuffix();
     KConfigGroup cg = config();
 
     ui.filechooser->setUrl(m_sourceFile);
@@ -191,6 +193,11 @@ void ParleyPlasma::createConfigurationInterface(KConfigDialog * parent)
     }
 }
 
+void ParleyPlasma::updateSpinBoxSuffix()
+{
+    ui.updateIntervalSpinBox->setSuffix(i18np(" second", " seconds", ui.updateIntervalSpinBox->value()));
+}
+
 void ParleyPlasma::urlSelected (const KUrl &file)
 {
     // turn off old engine
